@@ -2,7 +2,7 @@ package GCDialogs;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -297,20 +297,23 @@ $hasAboutDialog = 0 if $@;
         }) if $self->{scrollArea};
         my $code = $self->run;
         $self->hide;
+        $self->{windowParent}->showMe;
     }
 
     sub new
     {
-        my ($proto, $parent, $file) = @_;
+        my ($proto, $parent, $file, $windowParent) = @_;
         my $class = ref($proto) || $proto;
+        $windowParent ||= $parent;
         my $self  = $class->SUPER::new($parent->{lang}->{ImportViewPicture},
-                                       $parent,
+                                       $windowParent,
                                        [qw/modal destroy-with-parent/],
                                        'gtk-ok' => 'ok'
                                       );
         bless($self, $class);
 
         $self->{parent} = $parent;
+        $self->{windowParent} = $windowParent;
 
         if (-f $file)
         {
@@ -731,10 +734,10 @@ $hasAboutDialog = 0 if $@;
         $table->attach($self->{info}->{file}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
         $line++;
         
-        my $itemsLabel = new GCLabel($parent->{lang}->{PropertiesItemsNumber});
+        $self->{info}->{itemsLabel} = new GCLabel($parent->{lang}->{PropertiesItemsNumber});
         $self->{info}->{items} = new GCShortText;
         $self->{info}->{items}->lock(1);
-        $table->attach($itemsLabel, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
+        $table->attach($self->{info}->{itemsLabel}, 2, 3, $line, $line + 1, 'fill', 'fill', 0, 0);
         $table->attach($self->{info}->{items}, 3, 4, $line, $line + 1, ['expand', 'fill'], 'fill', 0, 0);
         $line++;
         
@@ -1506,7 +1509,7 @@ $hasAboutDialog = 0 if $@;
                 if (!$@)
                 {
                     $self->{ignoreFilter} = 0;
-                    $filterAll->set_name('*.*');
+                    $filterAll->set_name($self->{parent}->{lang}->{FileAllFiles});
                     $filterAll->add_pattern('*');
                     $self->{dialog}->add_filter($filterAll);
                     $self->{filters} = [];
@@ -1595,16 +1598,38 @@ $hasAboutDialog = 0 if $@;
             $self->{dialog}->remove_filter($_) foreach(@{$self->{filters}});
             $self->{filters} = [];
             $self->{filtersPatterns} = {};
-            foreach (@filters)
+            foreach my $filterPattern (@filters)
             {
                 my $filter;
                 eval '$filter = new Gtk2::FileFilter';
                 return if $@;
-                $filter->set_name($_->[0]);
-                $filter->add_pattern($_->[1]);
+                $filter->set_name($filterPattern->[0]);
+                if (ref($filterPattern->[1]))
+                {
+                    # Filter pattern is an array. Use a custom filter so file extensions are not case sensitive
+                    $filter->add_custom('filename', sub {
+                        my ($filename, undef, $extension) = fileparse(shift->{filename},qr{\.[^\.]*});
+                        $extension =~ s/[^\.\w]//g;
+                        $extension = lc($extension);
+                        return (grep {$_ eq $extension} @{$filterPattern->[1]});
+                    });
+
+                }
+                else
+                {
+                    # Filter pattern is single valid. Use a custom filter so file extensions are not case sensitive
+                    $filter->add_custom('filename', sub {
+                        my ($filename, undef, $extension) = fileparse(shift->{filename},qr{\..*});
+                        $extension =~ s/[^\.\w]//g;
+                        $extension = lc($extension);
+                        my $filterExt = $filterPattern->[1];
+                        $filterExt =~ s/^[^\.]*//;
+                        return ($extension eq $filterExt);
+                    });
+                }
                 push @{$self->{filters}}, $filter;
                 $self->{dialog}->add_filter($filter);
-                $self->{filtersPatterns}->{$_->[0]} = $_->[1];
+                $self->{filtersPatterns}->{$filterPattern->[0]} = $filterPattern->[1];
             }
             $self->{dialog}->set_filter($self->{filters}->[0]) if $self->{filters}->[0];
         }
