@@ -2,7 +2,7 @@ package GCExportImport;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -74,6 +74,17 @@ use strict;
         return 1;
     }
     
+    sub checkOptionalModule
+    {
+        my ($self, $module, $version) = @_;
+        # Save errors
+        my $errors = $self->{errors};
+        my $code = $self->checkModule($module, $version);
+        # And restore them so it won't impact detecting if the module is broken
+        $self->{errors} = $errors;
+        return $code;
+    }
+    
     sub new
     {
         my ($proto) = @_;
@@ -309,7 +320,6 @@ use GCDialogs;
                         my @values;
                         @values=split m/,/,$option->{valuesList} if(scalar($option->{valuesList}));
                         @values=@{$option->{valuesList}} if (UNIVERSAL::isa( $option->{valuesList}, "ARRAY" ));
-                          print ref $option->{valuesList};
                         foreach $value(@values)
                         {
                             my $item = {
