@@ -2,7 +2,7 @@ package GCImageLists;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -47,6 +47,7 @@ my $timeOutBetweenEnhancements = 50;
         my $parent = $container->{parent};
         
         $self->{preferences} = $parent->{model}->{preferences};
+        $self->{imagesDir} = $parent->getImagesDir();
         $self->{coverField} = $parent->{model}->{commonFields}->{cover};
         $self->{titleField} = $parent->{model}->{commonFields}->{title};
         $self->{borrowerField} = $parent->{model}->{commonFields}->{borrower}->{name};
@@ -73,9 +74,11 @@ my $timeOutBetweenEnhancements = 50;
         $self->set_border_width(0);
 
         $self->signal_connect('button_press_event' => sub {
-                my ($widget, $event) = @_;
+            my ($widget, $event) = @_;
+            if ($event->button eq 3)
+            {
                 $self->{parent}->{context}->popup(undef, undef, undef, undef, $event->button, $event->time)
-                    if $event->button eq 3;
+            }
         });
 
         $self->can_focus(1);
@@ -145,9 +148,7 @@ my $timeOutBetweenEnhancements = 50;
                 sub compare
                 {
                     return (
-                            $a->{title}
-                            cmp
-                            $b->{title}
+                            GCUtils::gccmp ($a->{title}, $b->{title})
                            );
                 }
                 if ($self->{currentOrder} == 1)
@@ -191,7 +192,7 @@ my $timeOutBetweenEnhancements = 50;
         if ($refresh)
         {
             $self->refresh(1, $splash);
-            $self->enhanceAllPictures;
+            $self->show_all;
         }
         
         $self->{initializing} = 0;
@@ -250,6 +251,11 @@ my $timeOutBetweenEnhancements = 50;
         delete $self->{collectionDir};
         # Determine new current displayed
         $self->{current} = $self->{idxToDisplayed}->{$currentIdx};
+        if ($self->{toBeSelectedLater})
+        {
+            $self->{parent}->display($self->select(-1));
+            $self->{toBeSelectedLater} = 0;
+        }
         #$self->show_all;
     }
 
@@ -326,9 +332,6 @@ my $timeOutBetweenEnhancements = 50;
         if ($refresh)
         {
             $self->refresh(0, $splash);
-            Glib::Timeout->add(1000,
-                               \&enhanceAllPictures,
-                               $self);
         }
         $self->{initializing} = 0;
     }
@@ -340,60 +343,95 @@ my $timeOutBetweenEnhancements = 50;
         my $init = $self->{initializing};
         $self->{initializing} = 1;
         $self->refresh($refresh);
-        $self->enhanceAllPictures;
+        $self->show_all;
         $self->{initializing} = $init;
     }
-
-    sub createPixbuf
+    
+    # Resizes artwork to required sizes and saves copies of the images, for fast loading
+    sub createImageCache
     {
-        my ($self, $displayedImage, $borrower, $favourite, $forceEnhancement) = @_;
-        my $pixbuf = undef;
-        if ($displayedImage)
+        my ($self, $srcImage, $useOverlays) = @_;
+
+        # Load in the original source image
+        my $origPixbuf = Gtk2::Gdk::Pixbuf->new_from_file($srcImage);
+        
+        # Make sure destination directory exists
+        if ( ! -e $self->{imagesDir})
         {
-            eval {
-                $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($displayedImage);
-            };
-        }
-        if ($@ || !$pixbuf)
-        {
-            $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{parent}->{defaultImage});
+            mkdir($self->{imagesDir});
         }
 
-        my $width;
-        my $height;
-        my $boxWidth = $self->{style}->{imgWidth};
-        my $boxHeight = $self->{style}->{imgHeight};
+        # Get original picture format
+        my ($picFormat, $picWidth, $picHeight) = Gtk2::Gdk::Pixbuf->get_file_info($srcImage);
 
-        my $overlayPaddingLeft; 
-        my $overlayPaddingRight;
-        my $overlayPaddingTop;
-        my $overlayPaddingBottom;
-        my $targetOverlayHeight;
-        my $targetOverlayWidth;
-        my $pixbufTempHeight;
-        my $pixbufTempWidth;
-        my $alpha = 1;
+        # Loop through possible sizes
+        for (my $size = 0; $size < 5; $size++) {
+            my $imgWidth;
+            my $imgHeight;
+            my $overlay;
+            
+            my $cacheFilename = $self->{imagesDir}.basename($srcImage).".cache.".$size;
+            $cacheFilename .= ".overlay"
+                if $useOverlays;
 
-        if ($self->{style}->{useOverlays})
+            # Get size for cached image
+            ($imgWidth, $imgHeight, $overlay) = $self->getDestinationImgSize($useOverlays, $size,
+                                                                            $picWidth,
+                                                                            $picHeight);                    
+            
+            # Scale pixbuf and save
+            my $scaledPixbuf = GCUtils::scaleMaxPixbuf($origPixbuf, $imgWidth, $imgHeight, 0, 0);
+            if ($picFormat->{name} eq 'jpeg')
+            {
+                $scaledPixbuf->save ($cacheFilename, 'jpeg', quality => '99');        
+            }
+            else
+            {
+                $scaledPixbuf->save ($cacheFilename, 'png');                    
+            }
+        }
+    }
+    
+    # Calculates height and width of list image
+    sub getDestinationImgSize
+    {
+        my ($self, $useOverlays, $size, $origWidth, $origHeight) = @_;
+        
+        my $imgWidth;
+        my $imgHeight;
+        my $overlay;
+        
+        # No overlays
+        $imgWidth = (exists $self->{parent}->{model}->{collection}->{options}->{defaults}->{listImageWidth})
+              ? $self->{parent}->{model}->{collection}->{options}->{defaults}->{listImageWidth}
+              : 120;
+        $imgHeight = (exists $self->{parent}->{model}->{collection}->{options}->{defaults}->{listImageHeight})
+                           ? $self->{parent}->{model}->{collection}->{options}->{defaults}->{listImageHeight}
+                           : 160;
+                               
+        if ($useOverlays)
         {
-
+            # Overlays
+            
             # Calculate size of list image with proportional size of overlay padding added
-            $pixbufTempHeight = (($self->{style}->{overlayPaddingTop} + $self->{style}->{overlayPaddingBottom})/$self->{style}->{overlayPixbuf}->get_height + 1) * $pixbuf->get_height;
-            $pixbufTempWidth = (($self->{style}->{overlayPaddingLeft} + $self->{style}->{overlayPaddingRight})/$self->{style}->{overlayPixbuf}->get_width + 1) * $pixbuf->get_width;
+            my $pixbufTempHeight = (($self->{style}->{overlayPaddingTop} + $self->{style}->{overlayPaddingBottom})/$self->{style}->{overlayPixbuf}->get_height + 1) * $origHeight;
+            my $pixbufTempWidth = (($self->{style}->{overlayPaddingLeft} + $self->{style}->{overlayPaddingRight})/$self->{style}->{overlayPixbuf}->get_width + 1) * $origWidth;
 
             # Find out target size of overlay, keeping the same ratio as the size calculated above (ie, list image + relative padding)
             my $ratio = $pixbufTempHeight / $pixbufTempWidth;
-            if (($pixbufTempWidth > $boxWidth) || ($pixbufTempHeight > $boxHeight))
+            my $targetOverlayHeight;
+            my $targetOverlayWidth;
+            if (($pixbufTempWidth > $imgWidth) || ($pixbufTempHeight > $imgHeight))
             {
-                if (($pixbufTempWidth * $boxHeight/$pixbufTempHeight) < $boxWidth )
+                if (($pixbufTempWidth * $imgHeight/$pixbufTempHeight) < $imgHeight )
                 {
-                    $targetOverlayHeight = $boxHeight;
-                    $targetOverlayWidth = int($boxHeight / $ratio);
+                    $targetOverlayHeight = $imgHeight;
+                    $targetOverlayWidth = int($imgHeight / $ratio);
                 }
                 else
                 {
-                    $targetOverlayHeight = int($boxWidth * $ratio);
-                    $targetOverlayWidth = $boxWidth;
+                    $targetOverlayHeight = int( $imgWidth * $ratio);
+                    $targetOverlayWidth =  $imgWidth;
                 }
             }
             else
@@ -404,26 +442,89 @@ my $timeOutBetweenEnhancements = 50;
             }
 
             # Calculate final offset amounts for target size of overlay
-            $overlayPaddingLeft = int($self->{style}->{overlayPaddingLeft} * $targetOverlayWidth / $self->{style}->{overlayPixbuf}->get_width);
-            $overlayPaddingRight = int($self->{style}->{overlayPaddingRight} * $targetOverlayWidth / $self->{style}->{overlayPixbuf}->get_width);
-            $overlayPaddingTop = int($self->{style}->{overlayPaddingTop} * $targetOverlayHeight / $self->{style}->{overlayPixbuf}->get_height);
-            $overlayPaddingBottom = int($self->{style}->{overlayPaddingBottom} * $targetOverlayHeight / $self->{style}->{overlayPixbuf}->get_height);
+            $overlay->{paddingLeft} = int($self->{style}->{overlayPaddingLeft} * $targetOverlayWidth / $self->{style}->{overlayPixbuf}->get_width);
+            $overlay->{paddingRight} = int($self->{style}->{overlayPaddingRight} * $targetOverlayWidth / $self->{style}->{overlayPixbuf}->get_width);
+            $overlay->{paddingTop} = int($self->{style}->{overlayPaddingTop} * $targetOverlayHeight / $self->{style}->{overlayPixbuf}->get_height);
+            $overlay->{paddingBottom} = int($self->{style}->{overlayPaddingBottom} * $targetOverlayHeight / $self->{style}->{overlayPixbuf}->get_height);
 
-            # Resize the list image to fit into the correct space
-            $pixbuf = GCUtils::scaleMaxPixbuf($pixbuf,
-                                              $boxWidth - $overlayPaddingLeft - $overlayPaddingRight,
-                                              $boxHeight - $overlayPaddingTop - $overlayPaddingBottom,
-                                              0,
-                                              $self->{initializing} && !$forceEnhancement);
-        }
-        else
+            $imgWidth = $imgWidth - $overlay->{paddingLeft} - $overlay->{paddingRight};
+            $imgHeight = $imgHeight - $overlay->{paddingTop} - $overlay->{paddingBottom};
+        }   
+
+        my $factor = ($size == 0) ? 0.5
+                        : ($size == 1) ? 0.8
+                        : ($size == 3) ? 1.5
+                        : ($size == 4) ? 2
+                        : 1;                        
+        $imgWidth *= $factor;
+        $imgHeight *= $factor;
+        
+        return ($imgWidth, $imgHeight, $overlay);
+    }
+    
+    sub createPixbuf
+    {
+        my ($self, $displayedImage, $borrower, $favourite, $forceEnhancement) = @_;
+        my $pixbuf = undef;
+        
+        # Item has a picture assigned
+        if ($displayedImage)
         {
-            # No overlays, simple case
-            $pixbuf = GCUtils::scaleMaxPixbuf($pixbuf,
-                                              $boxWidth,
-                                              $boxHeight,
-                                              0,
-                                              $self->{initializing} && !$forceEnhancement);
+            my $cacheFilename =$self->{imagesDir}.basename($displayedImage).".cache.".$self->{parent}->{options}->listImgSize;
+            $cacheFilename .= ".overlay"
+                if $self->{style}->{useOverlays};
+          
+            # Does cached image file exist? 
+            if (!(-e $cacheFilename))
+            {
+                # Need to generate the cached images, if original picture exists
+                $self->createImageCache($displayedImage, $self->{style}->{useOverlays})
+                    if (-e $displayedImage);
+            }
+            
+            # Grab cached image
+            eval {
+                $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($cacheFilename);
+            };
+        }
+
+        # No picture assigned or using assigned picture failed, so use collection default
+        if ($@ || !$pixbuf)
+        {
+            my $cacheFilename = $self->{imagesDir}.basename($self->{parent}->{defaultImage}).".cache.".$self->{parent}->{options}->listImgSize;
+                        $cacheFilename .= ".overlay"
+                if $self->{style}->{useOverlays};
+
+            # Does cached image file exist? 
+            if (!(-e $cacheFilename))
+            {
+                # Need to generate the cached images
+                $self->createImageCache($self->{parent}->{defaultImage}, $self->{style}->{useOverlays})
+                    if (-e $self->{parent}->{defaultImage});
+            }            
+            $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($cacheFilename);
+        }
+
+        my $width;
+        my $height;
+        my $boxWidth = $self->{style}->{imgWidth};
+        my $boxHeight = $self->{style}->{imgHeight};
+
+        my $overlay;
+        my $imgWidth;
+        my $imgHeight;
+        my $targetOverlayHeight;
+        my $targetOverlayWidth;
+        my $pixbufTempHeight;
+        my $pixbufTempWidth;
+        my $alpha = 1;
+
+        if ($self->{style}->{useOverlays})
+        {
+            # Need to call this to get the overlay padding        
+            ($imgWidth, $imgHeight, $overlay) = $self->getDestinationImgSize(1, 2,
+                                                                    $pixbuf->get_width,
+                                                                    $pixbuf->get_height);                    
         }
         $width = $pixbuf->get_width;
         $height = $pixbuf->get_height;
@@ -435,8 +536,8 @@ my $timeOutBetweenEnhancements = 50;
             if ($self->{style}->{withImage})
             {
                 # Using background, so center accordingly
-                my $offsetX = 5 * $self->{style}->{factor} + (($boxWidth - ($width + $overlayPaddingLeft + $overlayPaddingRight)) / 2);
-                my $offsetY = 15 * $self->{style}->{factor} + ($boxHeight - ($height + $overlayPaddingTop + $overlayPaddingBottom));
+                my $offsetX = 5 * $self->{style}->{factor} + (($boxWidth - ($width + $overlay->{paddingLeft} + $overlay->{paddingRight})) / 2);
+                my $offsetY = 15 * $self->{style}->{factor} + ($boxHeight - ($height + $overlay->{paddingTop} + $overlay->{paddingBottom}));
 
                 # Make an empty pixbuf to work within
                 my $tempPixbuf =Gtk2::Gdk::Pixbuf->new('rgb', 1, 8,
@@ -446,9 +547,9 @@ my $timeOutBetweenEnhancements = 50;
 
                 # Place cover in pixbuf
                 $pixbuf->composite($tempPixbuf,
-                                      $offsetX + $overlayPaddingLeft, $offsetY + $overlayPaddingTop, 
+                                      $offsetX + $overlay->{paddingLeft}, $offsetY + $overlay->{paddingTop}, 
                                       $width , $height,
-                                      $offsetX + $overlayPaddingLeft, $offsetY + $overlayPaddingTop, 
+                                      $offsetX + $overlay->{paddingLeft}, $offsetY + $overlay->{paddingTop}, 
                                       1, 1, 
                                       'nearest', 255);
                 $pixbuf = $tempPixbuf;
@@ -456,11 +557,11 @@ my $timeOutBetweenEnhancements = 50;
                 # Composite overlay picture
                 $self->{style}->{overlayPixbuf}->composite($pixbuf,
                                                   $offsetX, $offsetY,
-                                                  $width + $overlayPaddingLeft + $overlayPaddingRight,
-                                                  $height + $overlayPaddingTop + $overlayPaddingBottom,
+                                                  $width + $overlay->{paddingLeft} + $overlay->{paddingRight},
+                                                  $height + $overlay->{paddingTop} + $overlay->{paddingBottom},
                                                   $offsetX, $offsetY,
-                                                  ($width + $overlayPaddingLeft + $overlayPaddingRight) / $self->{style}->{overlayPixbuf}->get_width,
-                                                  ($height + $overlayPaddingTop + $overlayPaddingBottom) / $self->{style}->{overlayPixbuf}->get_height, 
+                                                  ($width + $overlay->{paddingLeft} + $overlay->{paddingRight}) / $self->{style}->{overlayPixbuf}->get_width,
+                                                  ($height + $overlay->{paddingTop} + $overlay->{paddingBottom}) / $self->{style}->{overlayPixbuf}->get_height, 
                                                   'nearest', 255);
 
                 # Overlay borrower image if required
@@ -470,10 +571,10 @@ my $timeOutBetweenEnhancements = 50;
                    $pixbuf->saturate_and_pixelate($pixbuf, .1, 0);
                    $self->{style}->{lendPixbuf}->composite($pixbuf,
                                                   $pixbuf->get_width - $self->{style}->{lendPixbuf}->get_width - $offsetX,
-                                                  $offsetY + $height + $overlayPaddingTop + $overlayPaddingBottom - $self->{style}->{lendPixbuf}->get_height,
+                                                  $offsetY + $height + $overlay->{paddingTop} + $overlay->{paddingBottom} - $self->{style}->{lendPixbuf}->get_height,
                                                   $self->{style}->{lendPixbuf}->get_width, $self->{style}->{lendPixbuf}->get_height,
                                                   $pixbuf->get_width - $self->{style}->{lendPixbuf}->get_width - $offsetX,
-                                                  $offsetY + $height + $overlayPaddingTop + $overlayPaddingBottom - $self->{style}->{lendPixbuf}->get_height,
+                                                  $offsetY + $height + $overlay->{paddingTop} + $overlay->{paddingBottom} - $self->{style}->{lendPixbuf}->get_height,
                                                   1, 1, 
                                                   'nearest', 255);
                 }
@@ -498,10 +599,10 @@ my $timeOutBetweenEnhancements = 50;
                     $reflect = $pixbuf->flip(0);
                     $reflect->composite(
                         $pixbuf,
-                        0, 2 * ($offsetY + $height + $overlayPaddingTop + $overlayPaddingBottom) - $pixbuf->get_height,
+                        0, 2 * ($offsetY + $height + $overlay->{paddingTop} + $overlay->{paddingBottom}) - $pixbuf->get_height,
                         $pixbuf->get_width,
-                        2 * ($pixbuf->get_height - $height - $offsetY - $overlayPaddingTop - $overlayPaddingBottom) - (10 * $self->{style}->{factor}),
-                        0, 2 * ($offsetY + $height + $overlayPaddingTop + $overlayPaddingBottom) - $pixbuf->get_height,
+                        2 * ($pixbuf->get_height - $height - $offsetY - $overlay->{paddingTop} - $overlay->{paddingBottom}) - (10 * $self->{style}->{factor}),
+                        0, 2 * ($offsetY + $height + $overlay->{paddingTop} + $overlay->{paddingBottom}) - $pixbuf->get_height,
                         1, 1,
                         'nearest', 100
                     );
@@ -532,15 +633,15 @@ my $timeOutBetweenEnhancements = 50;
             {
                 # Not using background, so we need to make an empty pixbuf which is right size for overlay first
                 my $tempPixbuf =Gtk2::Gdk::Pixbuf->new('rgb', 1, 8,
-                                                $width + $overlayPaddingLeft + $overlayPaddingRight,
-                                                $height + $overlayPaddingTop + $overlayPaddingBottom);
+                                                $width + $overlay->{paddingLeft} + $overlay->{paddingRight},
+                                                $height + $overlay->{paddingTop} + $overlay->{paddingBottom});
                 $tempPixbuf->fill(0x00000000);
                             
                 # Now, place list image inside empty pixbuf
                 $pixbuf->composite($tempPixbuf,
-                                      $overlayPaddingLeft, $overlayPaddingTop, 
+                                      $overlay->{paddingLeft}, $overlay->{paddingTop}, 
                                       $width , $height,
-                                      $overlayPaddingLeft, $overlayPaddingTop, 
+                                      $overlay->{paddingLeft}, $overlay->{paddingTop}, 
                                       1, 1, 
                                       'nearest', 255 * $alpha);
                 $pixbuf = $tempPixbuf;
@@ -548,11 +649,11 @@ my $timeOutBetweenEnhancements = 50;
                 # Place overlay on top of pixbuf
                 $self->{style}->{overlayPixbuf}->composite($pixbuf,
                                                   0, 0,
-                                                  $width + $overlayPaddingLeft + $overlayPaddingRight,
-                                                  $height + $overlayPaddingTop + $overlayPaddingBottom,
+                                                  $width + $overlay->{paddingLeft} + $overlay->{paddingRight},
+                                                  $height + $overlay->{paddingTop} + $overlay->{paddingBottom},
                                                   0, 0,
-                                                  ($width + $overlayPaddingLeft + $overlayPaddingRight) / $self->{style}->{overlayPixbuf}->get_width,
-                                                  ($height + $overlayPaddingTop + $overlayPaddingBottom) / $self->{style}->{overlayPixbuf}->get_height, 
+                                                  ($width + $overlay->{paddingLeft} + $overlay->{paddingRight}) / $self->{style}->{overlayPixbuf}->get_width,
+                                                  ($height + $overlay->{paddingTop} + $overlay->{paddingBottom}) / $self->{style}->{overlayPixbuf}->get_height, 
                                                   'nearest', 255 * $alpha);
 
                 # Overlay borrower image if required
@@ -662,42 +763,6 @@ my $timeOutBetweenEnhancements = 50;
 
         return $pixbuf;
     }
-
-    sub enhanceAllPictures
-    {
-        my $self = shift;
-        $self->show_all;
-        my $i = 1;
-        foreach (@{$self->{enhanceInformation}})
-        {
-            Glib::Timeout->add($self->{offset} + ($i * $timeOutBetweenEnhancements),
-                               \&enhancePicture,
-                               $_);
-              
-            $i++;
-        }
-        $self->{enhanced} = 1;
-        return 0;
-    }
-
-    sub enhancePicture
-    {
-        my $data = shift;
-        my $eventBox = $data->[1];
-        return if ! $eventBox->child;
-        my $self = $data->[0];
-        my $pixbuf = $self->createPixbuf($data->[2], $data->[3], $data->[4], 1);
-        $eventBox->child->set_from_pixbuf($pixbuf);
-        $self->{tooltips}->set_tip($eventBox, $data->[5], '');
-
-        if ($eventBox->{selected})
-        {
-            $self->clearPrevious;
-            $self->{previousPixbufs}->{$eventBox->{idx}} = $pixbuf;
-            $self->select($self->{displayedToIdx}->{$self->{current}}, 1, 1);
-        }
-        return 0;
-    }
     
     sub createEventBox
     {
@@ -706,7 +771,6 @@ my $timeOutBetweenEnhancements = 50;
         $eventBox->can_focus(1);
         # We store the index of the displayed data
         my $image = new Gtk2::Image;
-
         my $displayedImage = GCUtils::getDisplayedImage($info->{picture},
                                                         undef,
                                                         $self->{parent}->{options}->file,
@@ -860,7 +924,8 @@ my $timeOutBetweenEnhancements = 50;
             if $item->{mouseHandler};
         $item->{mouseHandler} = $eventBox->signal_connect('button_press_event' => sub {
             my ($widget, $event) = @_;
-            if ($event->type ne '2button-press')
+
+            if (($event->type ne '2button-press') && !(($event->button eq 3) && ($widget->{selected})))
             {
                 my $state = $event->get_state;
                 my $keepPrevious = 0;
@@ -898,8 +963,7 @@ my $timeOutBetweenEnhancements = 50;
             }
             
             $self->{parent}->displayInWindow if $event->type eq '2button-press';
-            $self->{parent}->{context}->popup(undef, undef, undef, undef, $event->button, $event->time)
-                if $event->button eq 3;
+            $self->{parent}->{context}->popup(undef, undef, undef, undef, $event->button, $event->time) if ($event->button eq 3);
             $widget->grab_focus;
             $self->{container}->setCurrentList($self);
         });
@@ -1226,7 +1290,7 @@ my $timeOutBetweenEnhancements = 50;
     {
         my ($self, $idx) = @_;
         my $previous = $self->{idxToDisplayed}->{$idx};
-        return if $previous == -1;
+        return if ($previous == -1) || (!defined $previous);
         $self->{boxes}->[$previous]->modify_bg('normal', $self->{style}->{inactiveBg})
             if (! $self->{style}->{withImage}) && $self->{boxes}->[$previous];
         $self->{boxes}->[$previous]->child->set_from_pixbuf($self->{previousPixbufs}->{$idx})
@@ -1273,20 +1337,30 @@ my $timeOutBetweenEnhancements = 50;
         my ($self, $idx, $init, $keepPrevious) = @_;
         $idx = $self->{displayedToIdx}->{0} if $idx == -1;
         my $displayed = $self->{idxToDisplayed}->{$idx};
+        if (! $self->{columns})
+        {
+            $self->{toBeSelectedLater} = 1;
+            return $idx;
+        }
         my @boxes = @{$self->{boxes}};
-        return $displayed if ! scalar(@boxes);
+        return $idx if ! scalar(@boxes);
         my $alreadySelected = 0;
         $alreadySelected = $boxes[$displayed]->{selected}
             if exists $boxes[$displayed];
         my $nbSelected = scalar keys %{$self->{selectedIndexes}};
 
-        return $displayed if $alreadySelected && ($nbSelected < 2) && (!$init);
+        return $idx if $alreadySelected && ($nbSelected < 2) && (!$init);
         if ($keepPrevious)
         {
             if (($alreadySelected) && ($nbSelected > 1))
             {
+
                 $self->restoreItem($idx);
-                return;
+                # Special case where user has deselect items, so now only one item is left selected
+                # and menus need to be updated to reflect that
+                $self->updateMenus(1)
+                    if $nbSelected <= 2;                
+                return $idx;
             }
             $self->{selectedIndexes}->{$idx} = 1;
         }
@@ -1295,6 +1369,7 @@ my $timeOutBetweenEnhancements = 50;
             $self->restorePrevious;
             $self->{selectedIndexes} = {$idx => 1};
         }
+                   
         $self->{current} = $displayed;
         if (! $self->{style}->{withImage})
         {
@@ -1312,9 +1387,32 @@ my $timeOutBetweenEnhancements = 50;
         $self->grab_focus;
         $self->{container}->setCurrentList($self)
             if $self->{container};
+        
+        # Update menu items to reflect number of items selected
+        $self->updateMenus(scalar keys %{$self->{selectedIndexes}});
         return $idx;        
     }
 
+    sub updateMenus
+    {    
+        # Update menu items to reflect number of items selected
+        my ($self, $nbSelected) = @_;
+        foreach (
+                 # Menu labels
+                 [$self->{parent}->{menubar}, 'duplicateItem', 'MenuDuplicate'],
+                 [$self->{parent}->{menubar}, 'deleteCurrentItem', 'MenuEditDeleteCurrent'],
+                 # Context menu labels
+                 [$self->{parent}, 'contextNewWindow', 'MenuNewWindow'],
+                 [$self->{parent}, 'contextDuplicateItem', 'MenuDuplicate'],
+                 [$self->{parent}, 'contextItemDelete', 'MenuEditDeleteCurrent'],
+                )
+        {
+            $self->{parent}->{menubar}->updateItem(
+                $_->[0]->{$_->[1]},
+                $_->[2].(($nbSelected > 1) ? 'Plural' : ''));
+        }
+    }
+
     sub setHeader
     {
         my ($self, $header) = @_;
@@ -1711,8 +1809,30 @@ my $timeOutBetweenEnhancements = 50;
         $self->{style}->{useOverlays} = ($parent->{options}->useOverlays) && ($parent->{model}->{collection}->{options}->{overlay}->{image});        
         $parent->{options}->listImgSkin($GCStyle::defaultList) if ! $parent->{options}->exists('listImgSkin');
         $self->{style}->{skin} = $parent->{options}->listImgSkin;
-        $self->{style}->{withReflect} = ($self->{style}->{withImage} && ($self->{style}->{skin} =~ /Glass/ )) ? 1 : 0;
+        # Reflect setting can be enabled using "withReflect=1" in the listbg style file
+        $self->{style}->{withReflect} = 0;
         $parent->{options}->listImgSize(2) if ! $parent->{options}->exists('listImgSize');
+        
+        my $bgdir;
+        # Load in extra settings from the style file
+        if ($self->{style}->{withImage})
+        {
+            $bgdir = $ENV{GCS_SHARE_DIR}.'/list_bg/'.$self->{style}->{skin};
+            if (open STYLE, $bgdir.'/style')
+            {
+                while (<STYLE>)
+                {
+                    chomp;
+                    next if !$_;
+                    m/^(.*?)\s*=\s*(.*)$/;
+                    my $item = $1;
+                    (my $value = $2) =~ s/^"(.*?)"$/$1/;
+                    $self->{style}->{$item} = $value;
+                }                
+                close STYLE;
+            }
+        }
+        
         # Sets image width/height (for size = 2), getting value from the collection model or setting to
         # default values of 120, 160 if not specified in model file
         $self->{style}->{imgWidth} = (exists $parent->{model}->{collection}->{options}->{defaults}->{listImageWidth})
@@ -1773,8 +1893,6 @@ my $timeOutBetweenEnhancements = 50;
 
         if ($self->{style}->{withImage})
         {
-            my $bgdir = $ENV{GCS_SHARE_DIR}.'/list_bg/'.$self->{style}->{skin};
-
             $self->{style}->{bgPixmap} = $bgdir.'/list_bg.png';
 
             my $tmpPixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{style}->{bgPixmap});
@@ -1807,7 +1925,6 @@ my $timeOutBetweenEnhancements = 50;
             my $blue   = int($colors[2] / 257);
             $self->{style}->{activeBgValue} = ($red << 16) + ($green << 8) + $blue;
 
-
             if ($self->{style}->{withReflect}) 
             {
                 $self->{style}->{foregroundPixbuf} = Gtk2::Gdk::Pixbuf->new_from_file($bgdir.'/list_fg.png');
@@ -1816,19 +1933,7 @@ my $timeOutBetweenEnhancements = 50;
                                                                     $self->{style}->{vboxHeight},
                                                                     1);
             }
-            if (open STYLE, $bgdir.'/style')
-            {
-                while (<STYLE>)
-                {
-                    chomp;
-                    next if !$_;
-                    m/^(.*?)\s*=\s*(.*)$/;
-                    my $item = $1;
-                    (my $value = $2) =~ s/^"(.*?)"$/$1/;
-                    $self->{style}->{$item} = $value;
-                }                
-                close STYLE;
-            }
+            
             $self->{groupBgFile} = $bgdir.'/group.png';
         }
         else
@@ -1895,29 +2000,7 @@ my $timeOutBetweenEnhancements = 50;
         $type = $self->{parent}->{model}->{fieldsInfo}->{$field}->{type}
             if defined $self->{parent}->{model}->{fieldsInfo}->{$field}->{type};
         
-        if ($field eq $self->{borrowerField})
-        {
-            $value = $self->{parent}->{lang}->{PanelNobody} if (! $value) || ($value eq 'none');
-        }
-        else
-        {
-            if ($type eq 'date')
-            {
-                $value = GCUtils::timeToStr($value, $self->{parent}->{options}->dateFormat);
-            }
-            elsif ($type =~ /list$/o)
-            {
-                $value = GCPreProcess::multipleListToArray($value);
-            }
-            elsif ($type eq 'options')
-            {
-                $value = $self->{parent}->{items}->valueToDisplayed($value, $field) || $value;
-            }
-            if ($field eq $self->{titleField})
-            {
-               $value = $self->{parent}->transformTitle($value);
-            }
-        }
+        $value = $self->{parent}->transformValue($value, $field, 1);
 
         if (ref($value) eq 'ARRAY')
         {
@@ -1972,16 +2055,21 @@ my $timeOutBetweenEnhancements = 50;
     {
         my ($self, $title) = @_;
         my $label;
+        my $fixedTitle = $title;
+        $fixedTitle =~ s/&/&amp;/;
+        $fixedTitle =~ s/</&lt;/;
+        $fixedTitle =~ s/>/&gt;/;        
+        
         if ($self->{style}->{withImage})
         {
             $label = new GCColorLabel(Gtk2::Gdk::Color->parse('#000000'));
-            $label->set_markup('<span '.$self->{style}->{groupStyle}.">$title</span>");
+            $label->set_markup('<span '.$self->{style}->{groupStyle}.">$fixedTitle</span>");
             GCUtils::setWidgetPixmap($label, $self->{groupBgFile});
         }
         else
         {
             $label = new GCColorLabel($self->{style}->{activeBg});
-            $label->set_markup('<span weight="bold" color="'.$self->{style}->{inactiveBg}->to_string."\">$title</span>");
+            $label->set_markup('<span weight="bold" color="'.$self->{style}->{inactiveBg}->to_string."\">$fixedTitle</span>");
         }
         $label->set_justify($self->{style}->{groupAlign});
         $label->set_padding($GCUtils::halfMargin, $GCUtils::halfMargin);
@@ -2237,6 +2325,7 @@ my $timeOutBetweenEnhancements = 50;
     sub getCurrentIdx
     {
         my $self = shift;
+        return 0 if !$self->{currentList};
         return $self->{currentList}->getCurrentIdx;
     }
 
