@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,10 @@
         'Charset' => 'Charset',
         'Header' => 'Игнориране на първия ред',
         'Separator' => 'Разделител',
+        'Plugin' => 'Сайт, който да бъде използван',
+        'UseFirst' => 'Избер на първия ако има много резултати',
+        'SearchField' => 'Search for items using',
+
      );
 }
 
