@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,10 @@
         'Charset' => 'Joc de caràcters',
         'Header' => 'Ignora la primera línia',
         'Separator' => 'Delimitador',
+        'Plugin' => 'Lloc a utilitzar',
+        'UseFirst' => 'Selecciona el primer si hi ha molts resultats',
+        'SearchField' => 'Cercar articles mitjançant',
+
      );
 }
 
