@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -37,16 +37,16 @@
         'SuffixesTooltip' => 'Una llista separada per comes de sufixes o extensions de fitxters a considerar',
         'Remove' => 'Per ser borrats dels noms',
         'RemoveTooltip' => 'Una llista separada per comes de paraules que haurien de ser borrades dels noms de fitxers per a crear els noms que es desen',
-        'Ask'=> 'Ask',
-        'AskEnd'=> 'Ask all at end',
-        'AddWithoutInfo'=> 'Add without infos',
-        'DontAdd'=> 'Do not add',
-        'TakeFirst' => 'Select first',
+        'Ask'=> 'Pregunta',
+        'AskEnd'=> 'Pregunta al final',
+        'AddWithoutInfo'=> 'Afegeix sense informació',
+        'DontAdd'=> 'No afegeixis',
+        'TakeFirst' => 'Selecciona primer',
         'MultipleResult'=> 'Ignora quan hi ha més d\'un resultat',
         'MultipleResultTooltip'=> 'El fitxer s\'afegirà sense recollir la informació si hi ha més d\'un resutat',
         'RemoveWholeWord' => 'Elimina només paraules senceres',
-        'NoResult'=> 'No results',
-        'NoResultTooltip'=> 'What do we do when no search results is return by the plugin',
+        'NoResult'=> 'Sense resultats',
+        'NoResultTooltip'=> 'Què feim quan no es retorna un resultat',
         'RemoveTooltipWholeWord' => 'Les paraules s\'eliminaran només si apareixen com paraules senceres',
         'RemoveRegularExpr' => 'Expressió regular',
         'RemoveTooltipRegularExpr' => 'Es considera que \'Esser eliminat dels noms\' és una expressió regular',
@@ -56,8 +56,8 @@
         'SkipFileFullPath' => 'basat en el camí cencer',
         'SkipFileFileName' => 'basat en el nom del fitxer',
         'SkipFileFileNameAndUpdate' => 'basat en el nom del fitxer (però actualitza el camí a la col·lecció)',
-        'InfoFromFileNameRegExp' => 'Parse file name with this regular expression',
-        'InfoFromFileNameRegExpTooltip' => 'Use this to retrieve infos from filename (applied after removing extension).\nLeave empty if not needed.\nKnown fields : \n$T:Title, $A:Alphabetised title, $Y:Release date, $S:Season, $E:Episode, $N:Alphabetised serie name, $x:Part number, $y: Total part number',
+        'InfoFromFileNameRegExp' => 'Analitza el nom de fitxer amb aquesta expressió regular',
+        'InfoFromFileNameRegExpTooltip' => 'Utilitza aquest per treure informació del nom de fitxer (després d\'eliminar l\'extensió). Deixa-ho buid si no fa falta. Camps coneguts: $T:Títol, $A:Títol alfabetitzat, $Y:Data de sortida, $S:Temporada, $E:Episodi, $N:Nom alfabetitzat de la sèrie , $x:Número de part, $y: Número total de parts',
 
      );
 
