@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Charset',
         'Header' => 'Ignorovat první řádek',
         'Separator' => 'Oddělovač',
+        'Plugin' => 'Použít server',
+        'UseFirst' => 'Při více výsledcích použít první',
+        'SearchField' => 'Search for items using',
      );
 }
 
