@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -23,7 +23,23 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
-    
+
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+   
     use strict;
     use base 'Exporter';
 
@@ -46,93 +62,99 @@ Seitenbetreiber <b>verboten</b>.
 Der Button unter den Elementen verweist Sie auf die jeweilige
 Webseite, von der die Informationen stammen.',
 
-    'AllItemsFiltered' => 'Kein Element erfüllt Ihre Filtereinstellungen.',
+        'AllItemsFiltered' => 'Kein Element erfüllt Ihre Filtereinstellungen.', # Accepts model codes
         
-	'InstallDirInfo' => 'Installiere nach ',
-	'InstallMandatory' => 'Erforderliche Komponenten',
-	'InstallOptional' => 'Optionale Komponenten',
-	'InstallErrorMissing' => 'Fehler : Die folgenden Komponenten müssen installiert sein: ',
-	'InstallPrompt' => 'Basisverzeichnis für die Installation [/usr/local]: ',
-	'InstallEnd' => 'Installation beendet',
-	'InstallNoError' => 'Keine Fehler',
-	'InstallLaunch' => 'Um die Anwendung zu verwenden starten Sie ',
-	'InstallDirectory' => 'Installationsverzeichnis',
-	'InstallTitle' => 'Installation von GCstar',
-	'InstallDependencies' => 'Abhängigkeiten',
-    'InstallPath' => 'Pfad',
-    'InstallOptions' => 'Optionen',
-	'InstallSelectDirectory' => 'Wählen Sie ein Basisverzeichnis für die Installation',
-	'InstallWithClean' => 'Daten im Installationsverzeichnis löschen',
-	'InstallWithMenu' => 'GCstar zum Anwendungsmenü hinzufügen',
-    'InstallNoPermission' => 'Fehler: Sie haben keine Schreibrechte im gewählten Verzeichnis',
-	'InstallMissingMandatory' => 'Abhängigkeiten können auf Ihrem System nicht gelöst werden. Sie müssen diese ergänzen, um GCstar installieren zu können.',
-	'InstallMissingOptional' => 'Einige unten aufgelistete optionale Abhängigkeiten können nicht gelöst werden. GCstar kann installiert werden, aber einige Eigenschaften werden nicht verfügbar sein.',
-	'InstallMissingNone' => 'Es gibt keine ungelösten Abhängigkeiten. Sie können mit der Installation fortfahren.',
-	'InstallOK' => 'OK',
-	'InstallMissing' => 'Fehlt',
-	'InstallMissingFor' => 'Fehlt für',
-    'InstallCleanDirectory' => 'Entferne GCstar\'s Dateien im Verzeichnis: ',
-    'InstallCopyDirectory' => 'Kopiere Dateien in Verzeichnis: ',
-    'InstallCopyDesktop' => 'Kopiere Desktop Datei nach: ',
+        'InstallDirInfo' => 'Installiere nach ',
+        'InstallMandatory' => 'Erforderliche Komponenten',
+        'InstallOptional' => 'Optionale Komponenten',
+        'InstallErrorMissing' => 'Fehler : Die folgenden Komponenten müssen installiert sein: ',
+        'InstallPrompt' => 'Basisverzeichnis für die Installation [/usr/local]: ',
+        'InstallEnd' => 'Installation beendet',
+        'InstallNoError' => 'Keine Fehler',
+        'InstallLaunch' => 'Um die Anwendung zu verwenden starten Sie ',
+        'InstallDirectory' => 'Installationsverzeichnis',
+        'InstallTitle' => 'Installation von GCstar',
+        'InstallDependencies' => 'Abhängigkeiten',
+        'InstallPath' => 'Pfad',
+        'InstallOptions' => 'Optionen',
+        'InstallSelectDirectory' => 'Wählen Sie ein Basisverzeichnis für die Installation',
+        'InstallWithClean' => 'Daten im Installationsverzeichnis löschen',
+        'InstallWithMenu' => 'GCstar zum Anwendungsmenü hinzufügen',
+        'InstallNoPermission' => 'Fehler: Sie haben keine Schreibrechte im gewählten Verzeichnis',
+        'InstallMissingMandatory' => 'Abhängigkeiten können auf Ihrem System nicht gelöst werden. Sie müssen diese ergänzen, um GCstar installieren zu können.',
+        'InstallMissingOptional' => 'Einige unten aufgelistete optionale Abhängigkeiten können nicht gelöst werden. GCstar kann installiert werden, aber einige Eigenschaften werden nicht verfügbar sein.',
+        'InstallMissingNone' => 'Es gibt keine ungelösten Abhängigkeiten. Sie können mit der Installation fortfahren.',
+        'InstallOK' => 'OK',
+        'InstallMissing' => 'Fehlt',
+        'InstallMissingFor' => 'Fehlt für',
+        'InstallCleanDirectory' => 'Entferne GCstar\'s Dateien im Verzeichnis: ',
+        'InstallCopyDirectory' => 'Kopiere Dateien in Verzeichnis: ',
+        'InstallCopyDesktop' => 'Kopiere Desktop Datei nach: ',
 
 #Update
-    'UpdateUseProxy' => 'Proxy (drücken Sie Enter für keinen): ',
-    'UpdateNoPermission' => 'Keine Schreibrechte im Verzeichnis: ',
-    'UpdateNone' => 'Keine Updates gefunden',
-    'UpdateFileNotFound' => 'Datei nicht gefunden',
+        'UpdateUseProxy' => 'Proxy (drücken Sie Enter für keinen): ',
+        'UpdateNoPermission' => 'Keine Schreibrechte im Verzeichnis: ',
+        'UpdateNone' => 'Keine Updates gefunden',
+        'UpdateFileNotFound' => 'Datei nicht gefunden',
 
 #Splash
-	'SplashInit' => 'Initialisiere',
-	'SplashLoad' => 'Lade Sammlung',
-    'SplashDisplay' => 'Sammlung anzeigen',
-    'SplashSort' => 'Sammlung sortieren',
-	'SplashDone' => 'Fertig',
+        'SplashInit' => 'Initialisiere',
+        'SplashLoad' => 'Lade Sammlung',
+        'SplashDisplay' => 'Sammlung anzeigen',
+        'SplashSort' => 'Sammlung sortieren',
+        'SplashDone' => 'Fertig',
 
 #Import from GCfilms
-    'GCfilmsImportQuestion' => 'Sie scheinen bereits GCfilms benutzt zu haben. Was möchten Sie von GCfilms nach GCstar importieren (die Daten von GCfilms bleiben erhalten)?',
-    'GCfilmsImportOptions' => 'Einstellungen',
-    'GCfilmsImportData' => 'Filmliste',
+        'GCfilmsImportQuestion' => 'Sie scheinen bereits GCfilms benutzt zu haben. Was möchten Sie von GCfilms nach GCstar importieren (die Daten von GCfilms bleiben erhalten)?',
+        'GCfilmsImportOptions' => 'Einstellungen',
+        'GCfilmsImportData' => 'Filmliste',
 
 #Menus
-	'MenuFile' => '_Datei',
-		'MenuNewList' => '_Neue Liste',
-		'MenuHistory' => '_Letzte Sammlung',
-		'MenuLend' => '_Verliehenes anzeigen',
-		'MenuImport' => '_Importieren',	
-		'MenuExport' => '_Exportieren',
+        'MenuFile' => '_Datei',
+        'MenuNewList' => '_Neue Liste',
+        'MenuStats' => 'Statistische Auswertung',
+        'MenuHistory' => '_Letzte Sammlung',
+        'MenuLend' => '_Verliehenes anzeigen', # Accepts model codes
+        'MenuImport' => '_Importieren',	
+        'MenuExport' => '_Exportieren',
+        'MenuAddItem' => '_Hinzufügen', # Accepts model codes
 
-	'MenuEdit'  => '_Bearbeiten',
-   	    'MenuDuplicate' => 'Element _duplizieren',
-		'MenuEditDeleteCurrent' => 'Element _entfernen',
+        'MenuEdit'  => '_Bearbeiten',
+        'MenuDuplicate' => '{1} _duplizieren', # Accepts model codes
+        'MenuDuplicatePlural' => '{X} _duplizieren', # Accepts model codes
+        'MenuEditSelectAllItems' => '_alle {X} auswählen', # Accepts model codes
+        'MenuEditDeleteCurrent' => '{1} _löschen', # Accepts model codes
+        'MenuEditDeleteCurrentPlural' => '{X} _löschen', # Accepts model codes  
         'MenuEditFields' => 'Felder _bearbeiten',
-		'MenuEditLockItems' => 'Liste _sperren',
+        'MenuEditLockItems' => 'Liste _sperren',
 
-	'MenuDisplay' => '_Filter',
+        'MenuDisplay' => '_Filter',
         'MenuSavedSearches' => 'Gespeicherte Suchanfragen',
         'MenuSavedSearchesSave' => 'Aktuelle Suchanfrage speichern',
         'MenuSavedSearchesEdit' => 'Gespeicherte Suchanfragen bearbeiten',
         'MenuAdvancedSearch' => 'Erweiterte Suche',
-		'MenuViewAllItems' => '_Alle Elemente anzeigen',
-		'MenuNoFilter' => '_Alle',
+        'MenuViewAllItems' => '_Alle {X} anzeigen', # Accepts model codes
+        'MenuNoFilter' => '_Alle',
 
-	'MenuConfiguration' => '_Einstellungen',
-		'MenuDisplayOptions' => 'Sichtbare _Felder',
-		'MenuBorrowers' => 'Ent_leiher',
-		'MenuToolbarConfiguration' => '_Werkzeugleiste konfigurieren',
+        'MenuConfiguration' => '_Einstellungen',
+        'MenuDisplayOptions' => 'Sichtbare _Felder',
+        'MenuBorrowers' => 'Ent_leiher',
+        'MenuToolbarConfiguration' => '_Werkzeugleiste konfigurieren',
         'MenuGenresConversion' => 'Genres _konvertieren',
 
-    'MenuBookmarks' => 'Meine _Sammlung',
+        'MenuBookmarks' => 'Meine _Sammlung',
         'MenuBookmarksAdd' => 'aktuelle Sammlung _hinzufügen',
         'MenuBookmarksEdit' => 'Sammlung _bearbeiten',
 
-	'MenuHelp' => '_Hilfe',
+        'MenuHelp' => '_Hilfe',
     	'MenuHelpContent' => '_Hilfe',
         'MenuAllPlugins' => 'Zeige _Plugins',
         'MenuBugReport' => '_Programmfehler melden',
-		'MenuAbout' => '_Über GCstar',
+        'MenuAbout' => '_Über GCstar',
+
+        'MenuNewWindow' => '{1} in neuem _Fenster zeigen', # Accepts model codes
+        'MenuNewWindowPlural' => '{X} in neuem _Fenster zeigen', # Accepts model codes
 
-	'MenuNewWindow' => 'Elemente in neuem _Fenster zeigen',
-        
         'ContextExpandAll' => 'alle ausklappen',
         'ContextCollapseAll' => 'alle zusammenklappen',
         'ContextChooseImage' => '_Bild wählen',
@@ -140,24 +162,27 @@ Webseite, von der die Informationen stammen.',
         'ContextImageEditor' => 'Bildbearbeitungsprogramm',
         'ContextImgFront' => 'Vorderseite',
         'ContextImgBack' => 'Rückseite',
+        'ContextChooseFile' => 'Datei auswählen',
+        'ContextChooseFolder' => 'Verzeichnis auswählen',
 
         'DialogEnterNumber' => 'Bitte geben Sie einen Wert ein',
 
-        'RemoveConfirm' => 'Wollen Sie dieses Element wirklich entfernen?',
-        'DefaultNewItem' => 'Neues Element',
-        'NewItemTooltip' => 'Element hinzufügen',
+        'RemoveConfirm' => 'Wollen Sie dieses Element wirklich löschen?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Sollen alle diese {X} wirklich gelöscht werden?', # Accepts model codes
+
+        'DefaultNewItem' => 'Neues Element', # Accepts model codes
+        'NewItemTooltip' => '{1} hinzufügen', # Accepts model codes
         'NoItemFound' => 'Element nicht gefunden. Möchten Sie auf einer anderen Seite suchen?',
         'OpenList' => 'Bitte wählen Sie eine Liste',
         'SaveList' => 'Bitte wählen Sie den Speicherort für die Liste',
         'SaveListTooltip' => 'Aktuelle Liste speichern',
-        'SaveCurrentList' => 'Möchten Sie die aktuelle Liste speichern?',
         'SaveUnsavedChanges' => 'Es gibt ungespeicherte Änderungen in Ihrere Sammlung. Wollen Sie diese speichern?',
         'SaveDontSave' => 'Nicht speichern',
         'PreferencesTooltip' => 'Ändern der Programmeinstellungen',
         'ViewTooltip' => 'Anzeige der Liste ändern',
-        'PlayTooltip' => 'Mit dem Film verknüpftes Video abspielen',
+        'PlayTooltip' => 'Mit dem Film verknüpftes Video abspielen', # Accepts model codes
         'PlayFileNotFound' => 'Abzuspielende Datei nicht gefunden in:',
-        'PlayRetry' => 'Retry',
+        'PlayRetry' => 'noch einmal versuchen',
 
         'StatusSave' => 'Speichere...',
         'StatusLoad' => 'Lade...',
@@ -175,10 +200,11 @@ Webseite, von der die Informationen stammen.',
         'OptionsOpenError'=> 'Kann die Einstellungen nicht laden: ',
         'OptionsSaveError'=> 'Kann die Einstellungen nicht speichern: ',
         'ErrorModelNotFound' => 'Folgendes Modell wurde nicht gefunden: ',
-        'ErrorModelUserDir' => 'Die Nutzerdefinierten Modelle sind in: ',        
-        'RandomTooltip' => 'Element für heute Abend vorschlagen',
-        'RandomError'=> 'Sie haben keine ungesehenen Elemente',
-        'RandomEnd'=> 'Keine weiteren Vorschläge verfügbar',
+        'ErrorModelUserDir' => 'Die nutzerdefinierten Modelle sind in: ', 
+               
+        'RandomTooltip' => '{1} für heute Abend vorschlagen',
+        'RandomError'=> 'Sie haben keine ungesehenen {X}', # Accepts model codes
+        'RandomEnd'=> 'Keine weiteren Vorschläge verfügbar', # Accepts model codes
         'RandomNextTip'=> 'Nächster Vorschlag',
         'RandomOkTip'=> 'Diesen Vorschlag akzeptieren',
         
@@ -195,7 +221,8 @@ Adolfo González : Programmierer
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Deutsche Übersetzung von Gabriel Meier und FrenkX',
-        'AboutDesign' => 'Logo und Webdesign von le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo und Webdesign von le Spektre',
         
         'ToolbarRandom' => 'Heute Abend',
         
@@ -207,9 +234,9 @@ http://le-spektre.org',
         'ModelSettings' => 'Einstellungen von Sammlungen',
         'ModelNewType' => 'Neuer Sammlungstyp',
         'ModelName' => 'Name des Sammlungstypes:',
-		'ModelFields' => 'Felder',
-		'ModelOptions'	=> 'Optionen',
-		'ModelFilters'	=> 'Filter',
+        'ModelFields' => 'Felder',
+        'ModelOptions'	=> 'Optionen',
+        'ModelFilters'	=> 'Filter',
         'ModelNewField' => 'Neues Feld',
         'ModelFieldInformation' => 'Information',
         'ModelFieldName' => 'Beschriftung:',
@@ -245,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Programm',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'zu benutzende Felder',
         'ModelOptionsFieldsAuto' => 'Automatisch',
         'ModelOptionsFieldsNone' => 'Keine',
@@ -262,7 +290,7 @@ http://le-spektre.org',
         'ModelFilterRegexp' => 'Regulärer Ausdruck',
         'ModelFilterRange' => 'Bereich',
         'ModelFilterNumeric' => 'numerischer Vergleich',
-		'ModelFilterQuick' => 'Schnellen Filter erstellen',
+        'ModelFilterQuick' => 'Schnellen Filter erstellen',
         'ModelTooltipName' => 'Benutzen Sie einen Namen, der in vielen Sammlungen verwendet werden kann. Wenn Sie nichts angeben, werden die Einstellungen direkt in der Sammlung gespeichert',
         'ModelTooltipLabel' => 'Der Feldname, so wie er angezeigt wird',
         'ModelTooltipGroup' => 'Kann zum gruppieren verwendet werden. Elemente ohne Gruppenangabe werden in einer vorgegebenen Gruppe zusammengefasst',
@@ -273,13 +301,13 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'In Vergleichsoperationen wird der Wert als Zahl interpretiert',
         'ModelTooltipQuick' => 'Fügt ein Untermenü zu "Filter" hinzu',
 
-        'ResultsTitle' => 'Wählen Sie einen Eintrag',
+        'ResultsTitle' => 'Wählen Sie einen Eintrag', # Accepts model codes
         'ResultsNextTip' => 'Auf der nächsten Seite suchen',
         'ResultsPreview' => 'Vorschau',
-        'ResultsInfo' => 'Es können mehrere Elemente durch Auswahl bei gedrückter STRG oder UMSCHALT Taste zu der Sammlung hinzugefügt werden.',
+        'ResultsInfo' => 'Es können mehrere Elemente durch Auswahl bei gedrückter STRG oder UMSCHALT Taste zu der Sammlung hinzugefügt werden.', # Accepts model codes
         
         'OptionsTitle' => 'Einstellungen',
-		'OptionsExpertMode' => 'Expertenmodus',
+        'OptionsExpertMode' => 'Expertenmodus',
         'OptionsPrograms' => 'Wählen Sie eine Anwendung für verschiedene Medientypen. Wird nichts eingetragen, werden die Voreinstellungen des Systems verwendet.',
         'OptionsBrowser' => 'Internetbrowser',
         'OptionsPlayer' => 'Videoabspielprogramm',
@@ -299,21 +327,21 @@ http://le-spektre.org',
         'OptionsTearoffMenus' => 'Ablösbare Menüs aktivieren',
         'OptionsSpellCheck' => 'Rechtschreibprüfung für lange Textfelder verwenden',
         'OptionsProgramTitle' => 'Wählen Sie die gewünschte Anwendung',
-		'OptionsPlugins' => 'Seite zum Bezug von Informationen',
-		'OptionsAskPlugins' => 'Fragen (Alle Seiten)',
-		'OptionsPluginsMulti' => 'Mehrere...',
-		'OptionsPluginsMultiAsk' => 'Fragen (Mehrere...)',
-        'OptionsPluginsMultiPerField' => 'Mehrere... (per field)',
-        'OptionsPluginsMultiPerFieldWindowTitle' => 'Many sites per field order selection',
-        'OptionsPluginsMultiPerFieldDesc' => 'For each selected field we will return the first non empty information beginning from left',
-        'OptionsPluginsMultiPerFieldFirst' => 'Anfang',
+        'OptionsPlugins' => 'Seite zum Bezug von Informationen',
+        'OptionsAskPlugins' => 'Fragen (Alle Seiten)',
+        'OptionsPluginsMulti' => 'Mehrere...',
+        'OptionsPluginsMultiAsk' => 'Fragen (Mehrere...)',
+        'OptionsPluginsMultiPerField' => 'Mehrere... (pro Feld)',
+        'OptionsPluginsMultiPerFieldWindowTitle' => 'Datenquellen für die einzeln Felder zuordnen',
+        'OptionsPluginsMultiPerFieldDesc' => 'Jedes ausgewählte Feld wird mit dem ersten gefunden Inhalt gefüllt, von links angefangen.',
+       'OptionsPluginsMultiPerFieldFirst' => 'Anfang',
         'OptionsPluginsMultiPerFieldLast' => 'Ende',
         'OptionsPluginsMultiPerFieldRemove' => 'Entfernen',
         'OptionsPluginsMultiPerFieldClearSelected' => 'Ausgewählte Feldliste leeren',
-		'OptionsPluginsList' => 'Sammlung bearbeiten',
+        'OptionsPluginsList' => 'Sammlung bearbeiten',
         'OptionsAskImport' => 'Zu importierende Felder wählen',
-		'OptionsProxy' => 'Proxy verwenden',
-		'OptionsCookieJar' => 'Nutze diese jar-Datei für Cookies',
+        'OptionsProxy' => 'Proxy verwenden',
+        'OptionsCookieJar' => 'Speichere Cookies in dieser Datei',
         'OptionsLang' => 'Sprache',
         'OptionsMain' => 'Allgemein',
         'OptionsPaths' => 'Pfade',
@@ -321,29 +349,29 @@ http://le-spektre.org',
         'OptionsConveniences' => 'Eigenschaften',
         'OptionsDisplay' => 'Anzeige',
         'OptionsToolbar' => 'Werkzeugleiste',
-		'OptionsToolbars' => {
-			0 => 'Keine', 
-			1 => 'Klein', 
-			2 => 'Groß', 
-			3 => 'Systemeinstellung'},
+        'OptionsToolbars' => {
+            0 => 'Keine', 
+            1 => 'Klein', 
+            2 => 'Groß', 
+            3 => 'Systemeinstellung'},
         'OptionsToolbarPosition' => 'Position',
         'OptionsToolbarPositions' => {
-			0 => 'Oben', 
-			1 => 'Unten', 
-			2 => 'Links', 
-			3 => 'Rechts'},
+            0 => 'Oben', 
+            1 => 'Unten', 
+            2 => 'Links', 
+            3 => 'Rechts'},
         'OptionsExpandersMode' => 'ausklappbare Zeile zu lang',
-		'OptionsExpandersModes' => {
-			'asis' => 'Unverändert', 
-			'cut' => 'Abschneiden', 
-			'wrap' => 'Zeilenumbruch'},
+        'OptionsExpandersModes' => {
+            'asis' => 'Unverändert', 
+            'cut' => 'Abschneiden', 
+            'wrap' => 'Zeilenumbruch'},
         'OptionsDateFormat' => 'Datumsformat',
         'OptionsDateFormatTooltip' => 'Das Format entspricht dem bei der Funktion strftime(3) genutzten. Voreinstellung ist %d/%m/%Y',
         'OptionsView' => 'Listenansicht',
         'OptionsViews' => {
-			0 => 'Text', 
-			1 => 'Bilder', 
-			2 => 'Detailliert'},
+            0 => 'Text', 
+            1 => 'Bilder', 
+            2 => 'Detailliert'},
         'OptionsColumns' => 'Spalten',
         'OptionsMailer' => 'E-Mail-Versand per',
         'OptionsSMTP' => 'Server',
@@ -356,7 +384,7 @@ http://le-spektre.org',
         'OptionsRestoreAccelerators' => 'Schnellzugriffe wiederherstellen',
         'OptionsHistory' => 'Größe des Verlaufs',
         'OptionsClearHistory' => 'Verlauf löschen',
-		'OptionsStyle' => 'Skin',
+        'OptionsStyle' => 'Skin',
         'OptionsDontAsk' => 'Nicht mehr fragen',
         'OptionsPathProgramsGroup' => 'Anwendungsprogramme',
         'OptionsProgramsSystem' => 'Nutze systemweite Einstellungen',
@@ -397,7 +425,7 @@ http://le-spektre.org',
         'DetailedOptionsImageSize' => 'Bildgröße',
         'DetailedOptionsGroupItems' => 'Gruppiere Elemente nach',
         'DetailedOptionsSecondarySort' => 'Sortiere gruppierte Felder nach',
-		'DetailedOptionsFields' => 'Anzuzeigende Felder wählen',
+        'DetailedOptionsFields' => 'Anzuzeigende Felder wählen',
         'DetailedOptionsGroupedFirst' => 'leere Elemente zusammenhalten',
         'DetailedOptionsAddCount' => 'Anzahl der enthaltenen Elemente anzeigen',
 
@@ -429,7 +457,7 @@ http://le-spektre.org',
         'ImportExportFileEmpty' => 'Sie müssen einen Dateinamen angeben',
         'ImportFieldsTitle' => 'Zu importierende Felder',
         'ImportFieldsTip' => 'Wählen Sie die zu importierenden Felder',
-        'ImportNewList' => 'Eine Neue Sammlung erstellen',
+        'ImportNewList' => 'Eine neue Sammlung erstellen',
         'ImportCurrentList' => 'Zur aktuellen Sammlung hinzufügen',
         'ImportDropError' => 'Es gab mindestens einen Fehler beim Öffnen der Dateien. Vorherige Liste wird wiederhergestellt.',
         'ImportGenerateId' => 'ID für jedes Element erzeugen',
@@ -438,6 +466,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Verzeichnis',
         'FileChooserOpenDirectory' => 'Wählen Sie ein Verzeichnis',
         'FileChooserOverwrite' => 'Diese Datei existiert bereits. Möchten Sie sie überschreiben?',
+        'FileAllFiles' => 'Alle Dateien',
+        'FileVideoFiles' => 'nur Video-Dateien',
+        'FileEbookFiles' => 'nur Ebook-Dateien',
+        'FileAudioFiles' => 'nur Audio-Dateien',
+        'FileGCstarFiles' => 'GCstar Sammlungen',
 
         'PanelCompact' => 'Komprimieren',
         'PanelReadOnly' => 'Nur Lesen',
@@ -455,28 +488,31 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Wählen Sie ein Bild',
         'PanelImageNoImage' => 'kein Bild',
         'PanelSelectFileTitle' => 'Datei auswählen',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Voreinstellung herstellen',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Noch offene Einträge aus dem Internet auffüllen',
 
         'PanelFrom' =>'Von',
         'PanelTo' =>'Bis',
 
         'PanelWeb' => 'Zeige Informationen',
-        'PanelWebTip' => 'Zeige Informationen über dieses Element im Internet',
-        'PanelRemoveTip' => 'Diesen Element entfernen',
+        'PanelWebTip' => 'Zeige Informationen über dieses Element im Internet', # Accepts model codes
+        'PanelRemoveTip' => 'Dieses Element entfernen', # Accepts model codes
 
         'PanelDateSelect' => 'Wählen Sie ein Datum',
         'PanelNobody' => 'Niemand',
         'PanelUnknown' => 'Unbekannt',
         'PanelAdded' => 'Hinzufügedatum',
         'PanelRating' => 'Bewertung',
-        'PanelPressRating' => 'Press Rating',
+        'PanelPressRating' => 'Fremdbewertung',
         'PanelLocation' => 'Ort',
 
         'PanelLending' => 'Verleih',
         'PanelBorrower'=> 'Entleiher',
         'PanelLendDate'=> 'verliehen am',
         'PanelHistory'=> 'Verlauf',
-        'PanelReturned' => 'Element zurückgegeben',
+        'PanelReturned' => 'Element zurückgegeben', # Accepts model codes
         'PanelReturnDate' => 'Rückgabedatum',
         'PanelLendedYes' => 'Verliehen',
         'PanelLendedNo' => 'Verfügbar',
@@ -509,9 +545,11 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Sprache',
         'PluginsUseSite' => 'Gewählte Seite für zukünftige Suchen verwenden',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Deaktiviert',
 
         'BorrowersTitle' => 'Entleiher bearbeiten',
-		'BorrowersList' => 'Entleiher',
+        'BorrowersList' => 'Entleiher',
         'BorrowersName' => 'Name',
         'BorrowersEmail' => 'E-Mail',
         'BorrowersAdd' => 'Hinzufügen',
@@ -527,9 +565,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Dateiformat:',
         'BorrowersImportFile' => 'Datei:',
 
-        'BorrowedTitle' => 'Verliehene Elemente',
+        'BorrowedTitle' => 'Verliehene Elemente', # Accepts model codes
         'BorrowedDate' => 'Seit',
-        'BorrowedDisplayInPanel' => 'Elemente im Hauptfenster anzeigen',
+        'BorrowedDisplayInPanel' => 'Elemente im Hauptfenster anzeigen', # Accepts model codes
 
         'MailTitle' => 'E-Mail senden',
         'MailFrom' => 'Von: ',
@@ -538,8 +576,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problem beim Verbinden zum SMTP-Server',
         'MailSendmailError' => 'Problem beim Starten von Sendmail',
 
-        'SearchTooltip' => 'Alle Elemente durchsuchen',
-        'SearchTitle' => 'Titelsuche',
+        'SearchTooltip' => 'Alle Elemente durchsuchen', # Accepts model codes
+        'SearchTitle' => 'Titelsuche', # Accepts model codes
         'SearchNoField' => 'Es wurden keine Felder für die Suchanfrage ausgewählt.
 Füge einige davon in der Filtersektion unter Einstellungen hinzu.',
 
@@ -578,7 +616,7 @@ Füge einige davon in der Filtersektion unter Einstellungen hinzu.',
         'PropertiesDescription' => 'Beschreibung',
         'PropertiesFile' => 'Dateieigenschaften',
         'PropertiesFilePath' => 'Vollständiger Pfad',
-        'PropertiesItemsNumber' => 'Anzahl enthaltener Elemente',
+        'PropertiesItemsNumber' => 'Anzahl enthaltener Elemente', # Accepts model codes
         'PropertiesFileSize' => 'Dateigröße',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Eigenschaften der Sammlung',
@@ -602,8 +640,8 @@ Füge einige davon in der Filtersektion unter Einstellungen hinzu.',
         'BookmarksNewFolder' => 'Neues Verzeichnis',
 
         'AdvancedSearchType' => 'Art der Suche',
-        'AdvancedSearchTypeAnd' => 'Elemente, die alle Kriterien erfüllen',
-        'AdvancedSearchTypeOr' => 'Elemente, die mindestens ein Kriterium erfüllen',
+        'AdvancedSearchTypeAnd' => 'Elemente, die alle Kriterien erfüllen', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Elemente, die mindestens ein Kriterium erfüllen', # Accepts model codes
         'AdvancedSearchCriteria' => 'Suchkriterium',
         'AdvancedSearchAnyField' => 'In allen Elementen',
         'AdvancedSearchSaveTitle' => 'Suchanfrage speichern',
@@ -617,6 +655,24 @@ Füge einige davon in der Filtersektion unter Einstellungen hinzu.',
         'BugReportPlatform' => 'Betriebssystem',
         'BugReportMessage' => 'Fehlermeldung',
         'BugReportInformation' => 'Zusätzliche Informationen',
+
+#Statistics
+        'StatsFieldToUse' => 'Auszuwertendes Feld',
+        'StatsSortByNumber' => 'Nach Anzahl der {X} sortieren',
+        'StatsGenerate' => 'Erzeugen',
+        'StatsKindOfGraph' => 'Diagrammart',
+        'StatsBars' => 'Balken',
+        'StatsPie' => 'Kuchen',
+        'Stats3DPie' => '3D Kuchen',
+        'StatsArea' => 'Fläche',
+        'StatsHistory' => 'Häufigkeitsverteilung',
+        'StatsWidth' => 'Breite',
+        'StatsHeight' => 'Höhe',
+        'StatsFontSize' => 'Schriftgröße',
+        'StatsDisplayNumber' => 'Häufigkeiten eintragen',
+        'StatsSave' => 'Diagramm als Grafik speichern',
+        'StatsAccumulate' => 'Werte zusammenzählen',
+        'StatsShowAllDates' => 'alle Daten berücksichtigen',
     );
 }
 1;
