@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Κωδικοποίηση χαρακτήρων',
         'Header' => 'Να αγνοηθεί η πρώτη γραμμή',
         'Separator' => 'Διαχωριστής',
+        'Plugin' => 'Ιστοσελίδες που θα χρησιμοποιηθούν',
+        'UseFirst' => 'Αν υπάρχουν περισσότερα αποτελέσματα να επιλέγεται το πρώτο',
+        'SearchField' => 'Search for items using',
      );
 }
 
