@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,7 +33,12 @@
     our %lang = (
     
         CollectionDescription => 'TV Shows (episodes) collection',
-        Items => 'Episodes',
+        Items => {  0 => 'Episodes',
+                    1 => 'Episode',
+                    X => 'Episodes',
+                    lowercase1 => 'episode',
+                    lowercaseX => 'episodes'
+                    },
         NewItem => 'New episode',
         NewSeries => 'New series',
         Episode => 'Episode',
