@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,9 +32,12 @@
     our %lang = (
     
         CollectionDescription => 'Books collection',
-        Items => {0 => 'Book',
+        Items => {0 => 'Books',
                   1 => 'Book',
-                  X => 'Books'},
+                  X => 'Books',
+                  lowercase1 => 'book',
+                  lowercaseX => 'books'
+                  },
         NewItem => 'New book',
     
         Isbn => 'ISBN',
@@ -57,6 +60,7 @@
         Url => 'Web page',
         Translator => 'Translator',
         Artist => 'Artist',
+        DigitalFile => 'Digital version',
 
         General => 'General',
         Details => 'Details',
