@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -32,7 +32,26 @@
     our %lang = (
     
         CollectionDescription => 'Colección de video juegos',
-        Items => 'Juegos',
+        Items => {0 => 'Juego',
+                  1 => 'Juego',
+                  lowercase1 => 'juego',
+                  X => 'Juegos',
+                  lowercaseX => 'juegos',
+                  P1 => 'El Juego',
+                  lowercaseP1 => 'el juego',
+                  U1 => 'Un Juego',
+                  lowercaseU1 => 'un juego',
+                  AP1 => 'Al Juego',
+                  lowercaseAP1 => 'al juego',
+                  DP1 => 'Del Juego',
+                  lowercaseDP1 => 'del juego',
+                  PX => 'Los Juegos',
+                  lowercasePX => 'los juegos',
+                  E1 => 'Este Juego',
+                  lowercaseE1 => 'este juego',
+                  EX => 'Estos Juegos',
+                  lowercaseEX => 'estos juegos'             
+                  },
         NewItem => 'Nuevo juego',
     
         Id => 'Id',
@@ -62,6 +81,11 @@
         Unlockables => 'Desbloqueables',
         Unlockable => 'Desbloqueable',
         Howto => 'Cómo desbloquear',
+        Exclusive => 'Exclusive',
+        Resolutions => 'Display resolutions',
+        InstallationSize => 'Size',
+        Region => 'Region',
+        SerialNumber => 'Serial Number',        
 
         General => 'General',
         Details => 'Detalles',
