@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -34,7 +34,15 @@
         CollectionDescription => 'Collection de jeux de société',
         Items => {0 => 'Jeu',
                   1 => 'Jeu',
-                  X => 'Jeux'},
+                  X => 'Jeux',
+                  I1 => 'Un jeu',
+                  D1 => 'Le jeu',
+                  DX => 'Les jeux',
+                  DD1 => 'Du jeu',
+                  M1 => 'Ce jeu',
+                  C1 => ' jeu',
+                  DA1 => 'e jeu',
+                  DAX => 'e jeux'},
         NewItem => 'Nouveau jeu',
     
         Id => 'Id',
