@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -34,7 +34,15 @@
         CollectionDescription => 'Collection de Bandes Dessinées',
         Items => {0 => 'Bandes Dessinées',
                   1 => 'Bande Dessinée',
-                  X => 'Bandes Dessinées'},
+                  X => 'Bandes Dessinées',
+                  I1 => 'Une bande dessinée',
+                  D1 => 'La bande dessinée',
+                  DX => 'Les bandes dessinées',
+                  DD1 => 'De la bande dessinée',
+                  M1 => 'Cette bande dessinée',
+                  C1 => 'e bande dessinée',
+                  DA1 => 'e bande dessinée',
+                  DAX => 'e bandes dessinées'},
         NewItem => 'Nouvelle BD',
 
 
