@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -24,6 +24,22 @@
 #
 ###################################################
 
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -48,7 +64,7 @@ Vous pourrez à tout instant connaître le site d\'où
 proviennent les informations d\'un élément en cliquant sur
 le <b>bouton situé en dessous de sa fiche</b>.',
 
-        'AllItemsFiltered' => 'Aucun élément ne correspond aux critères de filtrage',
+        'AllItemsFiltered' => 'Aucun{lowercaseC1} ne correspond aux critères de filtrage', # Accepts model codes
         
         'InstallDirInfo' => 'Installation dans ',
         'InstallMandatory' => 'Composants obligatoires',
@@ -98,14 +114,19 @@ le <b>bouton situé en dessous de sa fiche</b>.',
 #Menus
     	'MenuFile' => '_Fichier',
             'MenuNewList' => '_Nouvelle collection',
+            'MenuStats' => 'Statistiques',
             'MenuHistory' => 'Fichiers récemment ouverts',
-            'MenuLend' => 'Voir les éléments empruntés',
+            'MenuLend' => 'Voir les {lowercaseX} empruntés', # Accepts model codes
             'MenuImport' => '_Importer',
             'MenuExport' => '_Exporter',
+            'MenuAddItem' => '_Ajouter {lowercaseI1}', # Accepts model codes
     
         'MenuEdit'  => '_Edition',
-       	    'MenuDuplicate' => '_Dupliquer l\'élément',
-            'MenuEditDeleteCurrent' => 'Su_pprimer l\'élément courant',
+            'MenuDuplicate' => '_Dupliquer {lowercaseD1}', # Accepts model codes
+            'MenuDuplicatePlural' => '_Dupliquer {lowercaseDX}', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Selectionner tous {lowercaseDX}', # Accepts model codes
+            'MenuEditDeleteCurrent' => 'Su_pprimer {lowercaseD1} courant', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => 'Su_pprimer {lowercaseDX}', # Accepts model codes
             'MenuEditFields' => '_Changer les champs de la collection',
             'MenuEditLockItems' => 'Verroui_ller les informations',
     
@@ -114,7 +135,7 @@ le <b>bouton situé en dessous de sa fiche</b>.',
                 'MenuSavedSearchesSave' => 'Sauvegarder la recherche courante',
                 'MenuSavedSearchesEdit' => 'Modifier les recherches sauvegardées',
             'MenuAdvancedSearch' => 'Recherche _Avancée',
-            'MenuViewAllItems' => 'Voir _tous les éléments',
+            'MenuViewAllItems' => 'Voir _tous {lowercaseDX}', # Accepts model codes
             'MenuNoFilter' => '_Tous',
     
         'MenuConfiguration' => '_Configuration',
@@ -133,8 +154,9 @@ le <b>bouton situé en dessous de sa fiche</b>.',
             'MenuBugReport' => 'Signaler un _dysfonctionnement',
             'MenuAbout' => 'A _propos de GCstar',
     
-        'MenuNewWindow' => 'Afficher l\'élément dans une nouvelle fenêtre',
-                
+        'MenuNewWindow' => 'Afficher {lowercaseD1} dans une nouvelle fenêtre', # Accepts model codes
+        'MenuNewWindowPlural' => 'Afficher {lowercaseDX} dans une nouvelle fenêtre', # Accepts model codes
+
         'ContextExpandAll' => 'Tout développer',
         'ContextCollapseAll' => 'Tout réduire',
         'ContextChooseImage' => 'Changer l\'_image',
@@ -142,22 +164,25 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'ContextImageEditor' => 'Editeur d\'images',
         'ContextImgFront' => 'Recto',
         'ContextImgBack' => 'Verso',
+        'ContextChooseFile' => 'Sélectionner un fichier',
+        'ContextChooseFolder' => 'Sélectionner un répertoire',
 
         'DialogEnterNumber' => 'Veuillez entrer une valeur',
  
-        'RemoveConfirm' => 'Voulez-vous vraiment supprimer cet élément ?',
-        'DefaultNewItem' => 'Nouvel élément',
-        'NewItemTooltip' => 'Ajouter un nouvel élément',
-        'NoItemFound' => 'Aucun élément ne correspond. Voulez-vous tenter une recherche sur un autre site ?',
+        'RemoveConfirm' => 'Voulez-vous vraiment supprimer {lowercaseM1} ?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Voulez-vous vraiment supprimer ces {lowercaseX} ?', # Accepts model codes
+
+        'DefaultNewItem' => 'Nouvel élément', # Accepts model codes
+        'NewItemTooltip' => 'Ajouter {lowercaseI1}', # Accepts model codes
+        'NoItemFound' => 'Aucun{lowercaseC1} ne correspond. Voulez-vous tenter une recherche sur un autre site ?', # Accepts model codes
         'OpenList' => 'Quelle collection ouvrir ?',
         'SaveList' => 'Dans quel fichier enregistrer ?',
         'SaveListTooltip' => 'Enregistrer la liste courante',
-        'SaveCurrentList' => 'Vous devez d\'abord choisir dans quel fichier sauver la liste courante',
         'SaveUnsavedChanges' => 'Vous avez des changements non sauvegardés dans votre collection. Voulez-vous les sauvegarder ?',
         'SaveDontSave' => 'Ne pas enregistrer',
         'PreferencesTooltip' => 'Changer vos préférences',
         'ViewTooltip' => 'Changer le type de liste',
-        'PlayTooltip' => 'Lancer le fichier associé',
+        'PlayTooltip' => 'Lancer le fichier associé', # Accepts model codes
         'PlayFileNotFound' => 'Le fichier à lancer n\'a pas été trouvé dans cet emplacement :',
         'PlayRetry' => 'Réessayer',
         
@@ -180,8 +205,8 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'ErrorModelUserDir' => 'Les modèles créés par l\'utilisateur sont dans : ',
 
         'RandomTooltip' => 'Que vais-je regarder ce soir ?',
-        'RandomError'=> 'Vous n\'avez pas d\'élément pouvant être sélectionné',
-        'RandomEnd'=> 'Il n\'y a plus d\'autre élément',
+        'RandomError'=> 'Vous n\'avez pas d{lowercaseDA1} pouvant être sélectionné', # Accepts model codes
+        'RandomEnd'=> 'Il n\'y a plus d\'autre {lowercase1}', # Accepts model codes
         'RandomNextTip'=> 'Proposition suivante',
         'RandomOkTip'=> 'Accepter cet élément',
         
@@ -198,7 +223,8 @@ Adolfo González : Programmeur
 Logos Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Traduction française par Christian Jodar',
-        'AboutDesign' => 'Logo et webdesign par le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo et webdesign par le Spektre',
 
         'UnsavedCollection' => 'Collection non sauvegardée',
         'ModelsSelect' => 'Choisissez un type de collection',
@@ -246,6 +272,7 @@ http://le-spektre.org',
         'ModelFieldFileAudio' => 'Son',
         'ModelFieldFileProgram' => 'Programme',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Champs à utiliser',
         'ModelOptionsFieldsAuto' => 'Automatique',
         'ModelOptionsFieldsNone' => 'Aucun',
@@ -274,10 +301,10 @@ http://le-spektre.org',
         'ModelTooltipNumeric' => 'Indique que les valeurs doivent être considérées comme des nombres pour les comparaisons.',
         'ModelTooltipQuick' => 'Ajoutera un sous-menu dans le menu Filtres',
 
-        'ResultsTitle' => 'Choisissez un résultat',
+        'ResultsTitle' => 'Choisissez {lowercaseI1}', # Accepts model codes
         'ResultsNextTip' => 'Rechercher sur le site suivant',
         'ResultsPreview' => 'Aperçu',
-        'ResultsInfo' => 'Vous pouvez ajouter plusieurs éléments à la collection en maintenant la touche Shift ou Ctrl et en les sélectionnant',
+        'ResultsInfo' => 'Vous pouvez ajouter plusieurs {lowercaseX} à la collection en maintenant la touche Shift ou Ctrl et en les sélectionnant', # Accepts model codes
 
         'OptionsTitle' => 'Préférences',
 		'OptionsExpertMode' => 'Mode expert',
@@ -425,6 +452,11 @@ http://le-spektre.org',
         'FileChooserDirectory' => 'Répertoire',
         'FileChooserOpenDirectory' => 'Choisissez un répertoire',
         'FileChooserOverwrite' => 'Ce fichier existe. Voulez vous le remplacer ?',
+        'FileAllFiles' => 'Tous les fichiers',
+        'FileVideoFiles' => 'Fichier vidéos',
+        'FileEbookFiles' => 'Fichiers ebook (livres électroniques)',
+        'FileAudioFiles' => 'Fichiers sons',
+        'FileGCstarFiles' => 'Collections GCstar',
 
         'PanelCompact' => 'Compact',
         'PanelReadOnly' => 'Lecture seule',
@@ -442,14 +474,17 @@ http://le-spektre.org',
         'PanelImageTitle' => 'Sélectionnez une image',
         'PanelImageNoImage' => 'Pas d\'image',
         'PanelSelectFileTitle' => 'Sélectionnez un fichier',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Rétablir défaut',
+        'PanelRefresh' => 'Rafraîchir',
+        'PanelRefreshTip' => 'Mettre à jour les informations depuis Internet',
 
         'PanelFrom' =>'Entre',
         'PanelTo' =>'et',
 
         'PanelWeb' => 'Voir la fiche Internet',
-        'PanelWebTip' => 'Voir la fiche de l\'élément sur Internet',
-        'PanelRemoveTip' => 'Supprimer l\'élément affiché ci-dessus',
+        'PanelWebTip' => 'Voir la fiche {lowercaseDD1} sur Internet', # Accepts model codes
+        'PanelRemoveTip' => 'Supprimer {lowercaseD1} affiché ci-dessus', # Accepts model codes
 
         'PanelDateSelect' => 'Changer',
         'PanelNobody' => 'Personne',
@@ -463,7 +498,7 @@ http://le-spektre.org',
         'PanelBorrower' => 'Emprunteur',
         'PanelLendDate' => 'Date d\'emprunt',
         'PanelHistory' => 'Historique des emprunts',
-        'PanelReturned' => '_Rendu',
+        'PanelReturned' => '{1} _Rendu', # Accepts model codes
         'PanelReturnDate' => 'Date de retour',
         'PanelLendedYes' => 'Prêté',
         'PanelLendedNo' => 'Disponible',
@@ -497,6 +532,8 @@ http://le-spektre.org',
         'PluginsAuthor' => 'Auteur',
         'PluginsLang' => 'Langue',
         'PluginsUseSite' => 'Utiliser le site sélectionné pour les futures recherches',
+        'PluginsPreferredTooltip' => 'Site recommandé par GCstar',
+        'PluginDisabled' => 'Désactivé',
         
         'BorrowersTitle' => 'Configuration des emprunteurs',
         'BorrowersList' => 'Emprunteurs',
@@ -515,9 +552,9 @@ http://le-spektre.org',
         'BorrowersImportType' => 'Format du fichier :',
         'BorrowersImportFile' => 'Fichier :',
 
-        'BorrowedTitle' => 'Eléments empruntés',
+        'BorrowedTitle' => '{X} empruntés', # Accepts model codes
         'BorrowedDate' => 'Depuis le',
-        'BorrowedDisplayInPanel' => 'Voir dans la fenêtre principale',
+        'BorrowedDisplayInPanel' => 'Voir {lowercaseD1} dans la fenêtre principale', # Accepts model codes
 
         'MailTitle' => '_Envoyer un e-mail',
         'MailFrom' => 'De : ',
@@ -526,8 +563,8 @@ http://le-spektre.org',
         'MailSmtpError' => 'Problème de connexion au serveur SMTP',
         'MailSendmailError' => 'Problème au lancement de sendmail',
                 
-        'SearchTooltip' => 'Rechercher dans tous les éléments',
-        'SearchTitle' => 'Recherche d\'éléments',
+        'SearchTooltip' => 'Rechercher dans tous {lowercaseDX}', # Accepts model codes
+        'SearchTitle' => 'Recherche d{lowercaseDAX}', # Accepts model codes
         'SearchNoField' => 'Aucun champ n\'a été sélectionné pour la fenêtre de recherche.
 Ils peuvent être ajoutés dans l\'onglet Filtres des réglages de la collection.',
         
@@ -566,7 +603,7 @@ Ils peuvent être ajoutés dans l\'onglet Filtres des réglages de la collection
         'PropertiesDescription' => 'Description',
         'PropertiesFile' => 'Informations sur le fichier',
         'PropertiesFilePath' => 'Chemin complet',
-        'PropertiesItemsNumber' => 'Nombre d\'éléments',
+        'PropertiesItemsNumber' => 'Nombre d{lowercaseDAX}', # Accepts model codes
         'PropertiesFileSize' => 'Taille',
         'PropertiesFileSizeSymbols' => ['octets', 'Ko', 'Mo', 'Go', 'To', 'Po', 'Eo', 'Zo', 'Yo'],
         'PropertiesCollection' => 'Propriétés de la collection',
@@ -590,8 +627,8 @@ Ils peuvent être ajoutés dans l\'onglet Filtres des réglages de la collection
         'BookmarksNewFolder' => 'Nouveau répertoire',
 
         'AdvancedSearchType' => 'Type de recherche',
-        'AdvancedSearchTypeAnd' => 'Éléments correspondants à tous les critères',
-        'AdvancedSearchTypeOr' => 'Éléments correspondants à au moins un critère',
+        'AdvancedSearchTypeAnd' => '{X} correspondants à tous les critères', # Accepts model codes
+        'AdvancedSearchTypeOr' => '{X} correspondants à au moins un critère', # Accepts model codes
         'AdvancedSearchCriteria' => 'Critères',
         'AdvancedSearchAnyField' => 'N\'importe quel champ',
         'AdvancedSearchSaveTitle' => 'Sauvegarder la recherche',
@@ -605,6 +642,24 @@ Ils peuvent être ajoutés dans l\'onglet Filtres des réglages de la collection
         'BugReportPlatform' => 'Système d\'exploitation',
         'BugReportMessage' => 'Message d\'erreur',
         'BugReportInformation' => 'Informations complémentaires',
+
+#Statistics
+        'StatsFieldToUse' => 'Champ à utiliser',
+        'StatsSortByNumber' => 'Trier par nombre de {lowercaseX}',
+        'StatsGenerate' => 'Générer',
+        'StatsKindOfGraph' => 'Type de représentation',
+        'StatsBars' => 'Barres',
+        'StatsPie' => 'Camembert',
+        'Stats3DPie' => 'Camembert 3D',
+        'StatsArea' => 'Zones',
+        'StatsHistory' => 'Historique',
+        'StatsWidth' => 'Largeur',
+        'StatsHeight' => 'Hauteur',
+        'StatsFontSize' => 'Taille de la police',
+        'StatsDisplayNumber' => 'Montrer les valeurs',
+        'StatsSave' => 'Sauvegarder les statistiques dans un fichier',
+        'StatsAccumulate' => 'Accumuler les valeurs',
+        'StatsShowAllDates' => 'Montrer toutes les dates',
     );
 }
 1;
