@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -64,6 +64,11 @@
         Unlockables => 'Non bloqueables',
         Unlockable => 'Non bloqueable',
         Howto => 'Como desbloquear',
+        Exclusive => 'Exclusive',
+        Resolutions => 'Display resolutions',
+        InstallationSize => 'Size',
+        Region => 'Region',
+        SerialNumber => 'Serial Number',        
 
         General => 'Xeral',
         Details => 'Detalles',
