@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,7 +33,9 @@
     our %lang = (
     
         CollectionDescription => 'TV Shows (series) collection',
-        Items => 'Series',
+        Items => {0 => 'Series',
+                  1 => 'Series',
+                  X => 'Series'},
         NewItem => 'New series',
         Name => 'Name',
         Season => 'Season',
