@@ -4,7 +4,7 @@
     use utf8;
 ######################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -30,6 +30,22 @@
 #
 #######################################################
 
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -51,7 +67,7 @@ La loro redistributione senza l\'esplicita autorizzazione scritta dei siti web e
 
 Per determinare il sito web proprietario delle informazioni consultare l\'etichetta <b>[dettagli]</b>.',
         
-        'AllItemsFiltered' => 'Nessun articolo soddisfa ai criteri di filtro selezionati',
+        'AllItemsFiltered' => 'Nessun articolo soddisfa ai criteri di filtro selezionati', # Accepts model codes
 
 #Installation
         'InstallDirInfo' => 'Installazione in ',
@@ -102,14 +118,19 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
 #Menus
         'MenuFile' => 'File',
             'MenuNewList' => '_Nuova collezione',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => 'Ultime collezioni aperte',
-            'MenuLend' => 'Visualizza articoli prestati',
+            'MenuLend' => 'Visualizza articoli prestati', # Accepts model codes
             'MenuImport' => '_Importa',
             'MenuExport' => '_Esporta',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
 
 		'MenuEdit'  => 'Modifica',
-       	    'MenuDuplicate' => '_Duplica articolo',
-    		'MenuEditDeleteCurrent' => '_Rimuovi articolo corrente',
+            'MenuDuplicate' => '_Duplica articolo', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate articolos', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Articolos', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Rimuovi articolo corrente',, # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove articolo', # Accepts model codes  
             'MenuEditFields' => '_Cambia campi della collezione',
     		'MenuEditLockItems' => 'B_locca la collezione',
 
@@ -118,7 +139,7 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'Ricerca Avanzata',
-            'MenuViewAllItems' => 'Mostr_a tutti gli articoli',
+            'MenuViewAllItems' => 'Mostr_a tutti gli articoli', # Accepts model codes
             'MenuNoFilter' => 'Tutti',
         
         'MenuConfiguration' => 'Configurazione',
@@ -137,7 +158,8 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
             'MenuBugReport' => 'Segnala un _bug',
             'MenuAbout' => 'Su GCstar',
 
-        'MenuNewWindow' => 'Visulizza articoli in una nuova finestra',
+        'MenuNewWindow' => 'Visulizza articoli in una nuova finestra', # Accepts model codes
+        'MenuNewWindowPlural' => 'Visulizza articoli in una nuova finestra', # Accepts model codes
         
         'ContextExpandAll' => 'Espandi tutti',
         'ContextCollapseAll' => 'Collassa tutti',
@@ -146,22 +168,24 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'ContextImageEditor' => 'Image Editor', 
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
 
         'DialogEnterNumber' => 'Immetere valore',
 
-        'RemoveConfirm' => 'Desideri davvero rimuovere questo articolo?',
-        'DefaultNewItem' => 'Nuovo articolo',
-        'NewItemTooltip' => 'Aggiungi un nuovo articolo',
+        'RemoveConfirm' => 'Desideri davvero rimuovere questo articolo?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'Nuovo articolo', # Accepts model codes
+        'NewItemTooltip' => 'Aggiungi un nuovo articolo', # Accepts model codes
         'NoItemFound' => 'Nessun articolo trovato. Effettuare una ricerca su un altro sito?',
         'OpenList' => 'Scegliere collezione',
         'SaveList' => 'Scegli il nome e dove salvare la collezione',
         'SaveListTooltip' => 'Salva collezione corrente',
-        'SaveCurrentList' => 'Specificare dove salvare la collezione corrente',
         'SaveUnsavedChanges' => 'Ci sono modifiche alla collezione non ancora salvate. Salvarle?',
         'SaveDontSave' => 'Non salvare',
         'PreferencesTooltip' => 'Impostazione preferenze',
         'ViewTooltip' => 'Cambia visualizzazione',
-        'PlayTooltip' => 'Mostra il video associato all\'articolo',
+        'PlayTooltip' => 'Mostra il video associato all\'articolo', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -184,8 +208,8 @@ Per determinare il sito web proprietario delle informazioni consultare l\'etiche
         'ErrorModelUserDir' => 'User defined models are in: ',
 
         'RandomTooltip' => 'Articoli non visti',
-        'RandomError'=> 'Non ci sono articoli non visti',
-        'RandomEnd'=> 'Non ci sono piu\' articoli',
+        'RandomError'=> 'Non ci sono articoli non visti', # Accepts model codes
+        'RandomEnd'=> 'Non ci sono piu\' articoli', # Accepts model codes
         'RandomNextTip'=> 'Prossimo suggerimento',
         'RandomOkTip'=> 'Accetto questo articolo',
         
@@ -203,7 +227,8 @@ Logo Copyright le Spektre
 http://le-spektre.org',
         'AboutTranslation' => 'Traduzione italiana v1.0.2 - 2006-05-04 di: 
 Andreas Troschka - <swsolutions@om.it.eu.org>',
-        'AboutDesign' => 'Logo e webdesign di le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo e webdesign di le Spektre',
 
         'ToolbarRandom' => 'Non visti',
 
@@ -253,6 +278,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Programma',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Campi da utilizzare',
         'ModelOptionsFieldsAuto' => 'Automatico',
         'ModelOptionsFieldsNone' => 'Nessuno',
@@ -281,10 +307,10 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'ModelTooltipNumeric' => 'Nella comparazione i valori sono considerati numeri',
         'ModelTooltipQuick' => 'Aggiunge una voce di submenu\' nel menu\' filtri',
 
-        'ResultsTitle' => 'Seleziona un articolo',
+        'ResultsTitle' => 'Seleziona un articolo', # Accepts model codes
         'ResultsNextTip' => 'Cerca nel prossimo sito',
         'ResultsPreview' => 'Anteprima',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
         
         'OptionsTitle' => 'Preferenze',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -432,6 +458,11 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Seleziona un indice',
         'FileChooserOverwrite' => 'Questa collezione esiste gia\', sovrascriverla?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         'PanelCompact' => 'Compattare',
         'PanelReadOnly' => 'Sola lettura',
@@ -449,14 +480,17 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'PanelImageTitle' => 'Scegliere un\'immagine',
         'PanelImageNoImage' => 'Nessuna immagine',
         'PanelSelectFileTitle' => 'Seleziona un file',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Ripristina predefiniti',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
 
         'PanelWeb' => 'Leggi informazioni dell\'articolo',
-        'PanelWebTip' => 'Leggi informazioni su questo articolo e disponibili sul web',
-        'PanelRemoveTip' => 'Rimuovi l\'articolo corrente',
+        'PanelWebTip' => 'Leggi informazioni su questo articolo e disponibili sul web', # Accepts model codes
+        'PanelRemoveTip' => 'Rimuovi l\'articolo corrente', # Accepts model codes
 
         'PanelDateSelect' => 'Scegli una data',
         'PanelNobody' => 'Nessuno',
@@ -470,7 +504,7 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'PanelBorrower' => 'Prestiti',
         'PanelLendDate' => 'Data',
         'PanelHistory' => 'Cronologia',
-        'PanelReturned' => 'Articolo restituito',
+        'PanelReturned' => 'Articolo restituito', # Accepts model codes
         'PanelReturnDate' => 'Data restituzione',
         'PanelLendedYes' => 'Prestato',
         'PanelLendedNo' => 'Disponibile',
@@ -503,6 +537,8 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'PluginsAuthor' => 'Autore',
         'PluginsLang' => 'Lingua',
         'PluginsUseSite' => 'Utilizza il sito selezionato per ricerche future',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Configurazione prestiti',
         'BorrowersList' => 'Beneficiari dei prestiti',
@@ -521,9 +557,9 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'BorrowersImportType' => 'Formato file:',
         'BorrowersImportFile' => 'File:',
 
-        'BorrowedTitle' => 'Articoli prestati',
+        'BorrowedTitle' => 'Articoli prestati', # Accepts model codes
         'BorrowedDate' => 'Il',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'Manda una e-mail',
         'MailFrom' => 'Da: ',
@@ -532,8 +568,8 @@ Andreas Troschka - <swsolutions@om.it.eu.org>',
         'MailSmtpError' => 'Problema di connessione al server SMTP',
         'MailSendmailError' => 'Problema nell\'inviare l\'e-mail',
 
-        'SearchTooltip' => 'Cerca nella collezione',
-        'SearchTitle' => 'Cerca',
+        'SearchTooltip' => 'Cerca nella collezione', # Accepts model codes
+        'SearchTitle' => 'Cerca', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
         
@@ -572,7 +608,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Descrizione',
         'PropertiesFile' => 'Informazione file',
         'PropertiesFilePath' => 'Percorso completo',
-        'PropertiesItemsNumber' => 'Numero di articoli',
+        'PropertiesItemsNumber' => 'Numero di articoli', # Accepts model codes
         'PropertiesFileSize' => 'Dimensione',
         'PropertiesFileSizeSymbols' => ['Byte', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Proprieta\' collezione',
@@ -596,8 +632,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'Nuova cartella',
 
         'AdvancedSearchType' => 'Tipo di ricerca',
-        'AdvancedSearchTypeAnd' => 'Articoli soddisfacenti tutti i criteri (AND)',
-        'AdvancedSearchTypeOr' => 'Articoli soddisfacenti almeno un criterio (OR)',
+        'AdvancedSearchTypeAnd' => 'Articoli soddisfacenti tutti i criteri (AND)', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Articoli soddisfacenti almeno un criterio (OR)', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteri',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -611,6 +647,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Operating system',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
