@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,9 @@
         'Charset' => 'Charset',
         'Header' => 'Ignoră prima linie',
         'Separator' => 'Separator',
+        'Plugin' => 'Situl folosit',
+        'UseFirst' => 'Selectaţi primul în caz de prea multe rezultate',
+        'SearchField' => 'Search for items using',        
      );
 }
 
