@@ -4,7 +4,7 @@
     use utf8;
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -29,6 +29,22 @@
 # 
 ###################################################   
 
+#
+# MODEL-SPECIFIC CODES
+#
+# Some strings are modified to include the model-specific item type. Inside these strings,
+# any strings contained in {}'s will be replaced by the corresponding string from
+# the Item collection in the model language file. For example:
+#
+# {lowercase1} = {Items}->{lowercase1} (item type, singular, all lowercase). EG: game, movie, book
+# {1} = {Items}->{1} (item type, singular, with first letter uppercase). EG: Game, Movie, Book
+# {lowercaseX} = {Items}->{lowercaseX} (item type, multiple, lowercase). EG: games, movies, books
+# {X} = {Items}->{X} (item type, multiple, with first letter uppercase). EG Games, Movies, Books    
+#
+# GCstar will automatically convert these codes to the relevant translated string. You can 
+# use these codes in any string marked by a "Accepts model codes" comment.    
+#
+
     use strict;
     use base 'Exporter';
 
@@ -50,7 +66,7 @@ Bu bilgilerin, ilgili sitenin izni olmaksızın dağıtımı
 
 Bilginin hangi siteden alındığını <b>film detaylarının altındaki link düğmesinden öğrenebilirsiniz.</b>.',
         
-        'AllItemsFiltered' => 'Aradığınız anahtar sözcükle ilişkili bir film bulunamadı.',
+        'AllItemsFiltered' => 'Aradığınız anahtar sözcükle ilişkili bir film bulunamadı.', # Accepts model codes
         
 #Installation
         'InstallDirInfo' => 'Kurulum klasörü ',
@@ -101,14 +117,19 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
 #Menus
         'MenuFile' => '_Dosya',
             'MenuNewList' => '_Yeni Kolleksiyon',
+            'MenuStats' => 'Statistics',
             'MenuHistory' => '_Son Kullanılanlar',
-            'MenuLend' => 'Ö_dünç Verilenler',
+            'MenuLend' => 'Ö_dünç Verilenler', # Accepts model codes
             'MenuImport' => '_Al',	
             'MenuExport' => '_Ver',
+            'MenuAddItem' => '_Add Items', # Accepts model codes
     
         'MenuEdit'  => 'Düz_enle',
-            'MenuDuplicate' => '_Kopyasını oluştur',
-            'MenuEditDeleteCurrent' => '_Sil',
+            'MenuDuplicate' => '_Kopyasını oluştur', # Accepts model codes
+            'MenuDuplicatePlural' => 'Du_plicate Items', # Accepts model codes
+            'MenuEditSelectAllItems' => 'Select _All Items', # Accepts model codes
+            'MenuEditDeleteCurrent' => '_Sil', # Accepts model codes
+            'MenuEditDeleteCurrentPlural' => '_Remove Items', # Accepts model codes  
             'MenuEditFields' => '_Change collection fields',
             'MenuEditLockItems' => '_Veritabanını kilitle',
     
@@ -117,7 +138,7 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
                 'MenuSavedSearchesSave' => 'Save current search',
                 'MenuSavedSearchesEdit' => 'Modify saved searches',
             'MenuAdvancedSearch' => 'A_dvanced Search',
-            'MenuViewAllItems' => 'Tümünü Göste',
+            'MenuViewAllItems' => 'Tümünü Göste', # Accepts model codes
             'MenuNoFilter' => '_Hepsi',
     
         'MenuConfiguration' => '_Ayarlar',
@@ -136,7 +157,8 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
             'MenuBugReport' => 'Report a _bug',
             'MenuAbout' => 'GCstar _Hakkında',
     
-        'MenuNewWindow' => '_Yeni Pencerede Göster',
+        'MenuNewWindow' => '_Yeni Pencerede Göster', # Accepts model codes
+        'MenuNewWindowPlural' => 'Show Items in _New Window', # Accepts model codes
         
         'ContextExpandAll' => 'Hepsini Aç',
         'ContextCollapseAll' => 'Hepsini Kapa',
@@ -145,22 +167,24 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'ContextImageEditor' => 'Image Editor',
         'ContextImgFront' => 'Front',
         'ContextImgBack' => 'Back',
+        'ContextChooseFile' => 'Choose a File',
+        'ContextChooseFolder' => 'Choose a Folder',
         
         'DialogEnterNumber' => 'Lütfen bir değer giriniz',
 
-        'RemoveConfirm' => 'Bu başlığı silmek istediğinize emin misiniz?',
-        'DefaultNewItem' => 'New item',
-        'NewItemTooltip' => 'Yeni başlık eklemek için tıklayın',
+        'RemoveConfirm' => 'Bu başlığı silmek istediğinize emin misiniz?', # Accepts model codes
+        'RemoveConfirmPlural' => 'Do you really want to remove these items?', # Accepts model codes
+        'DefaultNewItem' => 'New item', # Accepts model codes
+        'NewItemTooltip' => 'Yeni başlık eklemek için tıklayın', # Accepts model codes
         'NoItemFound' => 'Aradığınız başlık bulunamadı. Başka bir siteden arama yapmak ister misiniz?',
         'OpenList' => 'Lütfen bir veritabanı seçin',
         'SaveList' => 'Listeyi nereye kaydedeceğiniz seçiniz',
         'SaveListTooltip' => 'Açık olan veritabanını kaydetmek için tıklayınız',
-        'SaveCurrentList' => 'Listeyi nereye kaydedeceğiniz seçiniz',
         'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
         'SaveDontSave' => 'Don\'t save',
         'PreferencesTooltip' => 'Ayarları yapmak için tıklayınız',
         'ViewTooltip' => 'Koleksiyonun görsel ayarlarını değiştirir',
-        'PlayTooltip' => 'Dosyayı lişkilendirilmiş oynatıcı ile başlatır',
+        'PlayTooltip' => 'Dosyayı lişkilendirilmiş oynatıcı ile başlatır', # Accepts model codes
         'PlayFileNotFound' => 'File to launch was not found in this location:',
         'PlayRetry' => 'Retry',
 
@@ -183,8 +207,8 @@ Bilginin hangi siteden alındığını <b>film detaylarının altındaki link d
         'ErrorModelUserDir' => 'User defined models are in: ',
         
         'RandomTooltip' => 'Bana öneride bulun. Rastgele dosya seçer.',
-        'RandomError'=> 'Tüm başlıkları izlemişsiniz ya da veritanında başlık yok.',
-        'RandomEnd'=> 'Tüm başlıkları izlemişsiniz. Başka başlık kalmadı.',
+        'RandomError'=> 'Tüm başlıkları izlemişsiniz ya da veritanında başlık yok.', # Accepts model codes
+        'RandomEnd'=> 'Tüm başlıkları izlemişsiniz. Başka başlık kalmadı.', # Accepts model codes
         'RandomNextTip'=> 'Bir Sonraki Öneri',
         'RandomOkTip'=> 'Tamam bu iyi',
         
@@ -201,7 +225,8 @@ Adolfo González: Programcı
 Logoların telif hakları le Spektre
 http://le-spektre.org\'a aittir.',
         'AboutTranslation' => 'Türkçe çeviri KaraGarga\'ya aittir',
-        'AboutDesign' => 'Logo ve webtasarımı: le Spektre',
+        'AboutDesign' => 'Łukasz Kowalczk (Qoolman): Skin Designer
+Logo ve webtasarımı: le Spektre',
 
         'ToolbarRandom' => 'Gece',
 
@@ -251,6 +276,7 @@ http://le-spektre.org\'a aittir.',
         'ModelFieldFileAudio' => 'Audio',
         'ModelFieldFileProgram' => 'Program',
         'ModelFieldFileUrl' => 'URL',
+        'ModelFieldFileEbook' => 'Ebook',
         'ModelOptionsFields' => 'Fields to use',
         'ModelOptionsFieldsAuto' => 'Automatic',
         'ModelOptionsFieldsNone' => 'None',
@@ -279,10 +305,10 @@ http://le-spektre.org\'a aittir.',
         'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
         'ModelTooltipQuick' => 'This will add a submenu in the Filters one',
         
-        'ResultsTitle' => 'Bir başlık seçiniz',
+        'ResultsTitle' => 'Bir başlık seçiniz', # Accepts model codes
         'ResultsNextTip' => 'Bir sonraki sitede ara',
         'ResultsPreview' => 'Preview',
-        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them',
+        'ResultsInfo' => 'You can add multiple items to the collection by holding down the Ctrl or the Shift key and selecting them', # Accepts model codes
         
         'OptionsTitle' => 'Ayarlar',
 		'OptionsExpertMode' => 'Expert Mode',
@@ -430,6 +456,11 @@ http://le-spektre.org\'a aittir.',
         'FileChooserDirectory' => 'Directory',
         'FileChooserOpenDirectory' => 'Bir Klasör Seçiniz',
         'FileChooserOverwrite' => 'Bu dosya zaten var. Üzerine yazmak istediğinizden emin misiniz?',
+        'FileAllFiles' => 'All Files',
+        'FileVideoFiles' => 'Video Files',
+        'FileEbookFiles' => 'Ebook Files',
+        'FileAudioFiles' => 'Audio Files',
+        'FileGCstarFiles' => 'GCstar Collections',
 
         #Some default panels
         'PanelCompact' => 'İşlevsel',
@@ -448,14 +479,17 @@ http://le-spektre.org\'a aittir.',
         'PanelImageTitle' => 'Kapak seç',
         'PanelImageNoImage' => 'No image',
         'PanelSelectFileTitle' => 'Dosya Seçiniz',
+        'PanelLaunch' => 'Launch',        
         'PanelRestoreDefault' => 'Restore default',
+        'PanelRefresh' => 'Update',
+        'PanelRefreshTip' => 'Update information from web',
 
         'PanelFrom' =>'From',
         'PanelTo' =>'To',
 
         'PanelWeb' => 'Bilgileri göster',
-        'PanelWebTip' => 'Bu filmin internet bilgisini göster',
-        'PanelRemoveTip' => 'Seçili filmi siliniz',
+        'PanelWebTip' => 'Bu filmin internet bilgisini göster', # Accepts model codes
+        'PanelRemoveTip' => 'Seçili filmi siliniz', # Accepts model codes
 
         'PanelDateSelect' => 'Tarih Seçiniz',
         'PanelNobody' => 'Kimse',
@@ -469,7 +503,7 @@ http://le-spektre.org\'a aittir.',
         'PanelBorrower' => 'Ödünç Alan',
         'PanelLendDate' => 'Ödünç Verme Tarihi',
         'PanelHistory' => 'Ödünç Geçmişi',
-        'PanelReturned' => 'Geri Dönme Tarihi',
+        'PanelReturned' => 'Geri Dönme Tarihi', # Accepts model codes
         'PanelReturnDate' => 'Geri dönme tarihi',
         'PanelLendedYes' => 'Ödün verilme',
         'PanelLendedNo' => 'Arşivde',
@@ -502,6 +536,8 @@ http://le-spektre.org\'a aittir.',
         'PluginsAuthor' => 'Yazarı',
         'PluginsLang' => 'Dil',
         'PluginsUseSite' => 'Her zaman bu siteyi kullan',
+        'PluginsPreferredTooltip' => 'Site recommended by GCstar',
+        'PluginDisabled' => 'Disabled',
 
         'BorrowersTitle' => 'Ödünç Seçenekleri',
         'BorrowersList' => 'Borrowers',
@@ -520,9 +556,9 @@ http://le-spektre.org\'a aittir.',
         'BorrowersImportType' => 'File format:',
         'BorrowersImportFile' => 'File:',
 
-        'BorrowedTitle' => 'Ödünç verilmiş filmler',
+        'BorrowedTitle' => 'Ödünç verilmiş filmler', # Accepts model codes
         'BorrowedDate' => 'Alma Tarihi',
-        'BorrowedDisplayInPanel' => 'Show item in main window',
+        'BorrowedDisplayInPanel' => 'Show item in main window', # Accepts model codes
 
         'MailTitle' => 'E-posta gönder',
         'MailFrom' => 'Kimden: ',
@@ -531,8 +567,8 @@ http://le-spektre.org\'a aittir.',
         'MailSmtpError' => 'SMTP sunucusuna bağlanamıyor',
         'MailSendmailError' => 'Sendmail istemcisini çalıştıramıyor',
 
-        'SearchTooltip' => 'Detaylı arama için tıklayınız',
-        'SearchTitle' => 'Film Arama',
+        'SearchTooltip' => 'Detaylı arama için tıklayınız', # Accepts model codes
+        'SearchTitle' => 'Film Arama', # Accepts model codes
         'SearchNoField' => 'No field have been selected for the search box.
 Add some of them in the Filters tab of the collection settings.',
 
@@ -571,7 +607,7 @@ Add some of them in the Filters tab of the collection settings.',
         'PropertiesDescription' => 'Description',
         'PropertiesFile' => 'File Information',
         'PropertiesFilePath' => 'Full path',
-        'PropertiesItemsNumber' => 'Number of items',
+        'PropertiesItemsNumber' => 'Number of items', # Accepts model codes
         'PropertiesFileSize' => 'Size',
         'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
         'PropertiesCollection' => 'Collection properties',
@@ -595,8 +631,8 @@ Add some of them in the Filters tab of the collection settings.',
         'BookmarksNewFolder' => 'New folder',
 
         'AdvancedSearchType' => 'Type of search',
-        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
-        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
+        'AdvancedSearchTypeAnd' => 'Items matching all criteria', # Accepts model codes
+        'AdvancedSearchTypeOr' => 'Items matching at least one criterion', # Accepts model codes
         'AdvancedSearchCriteria' => 'Criteria',
         'AdvancedSearchAnyField' => 'Any field',
         'AdvancedSearchSaveTitle' => 'Save search',
@@ -610,6 +646,24 @@ Add some of them in the Filters tab of the collection settings.',
         'BugReportPlatform' => 'Operating system',
         'BugReportMessage' => 'Error message',
         'BugReportInformation' => 'Additional information',
+
+#Statistics
+        'StatsFieldToUse' => 'Field to use',
+        'StatsSortByNumber' => 'Sort by number of {lowercaseX}',
+        'StatsGenerate' => 'Generate',
+        'StatsKindOfGraph' => 'Kind of graphic',
+        'StatsBars' => 'Bars',
+        'StatsPie' => 'Pie',
+        'Stats3DPie' => '3D Pie',
+        'StatsArea' => 'Areas',
+        'StatsHistory' => 'History',
+        'StatsWidth' => 'Width',
+        'StatsHeight' => 'Height',
+        'StatsFontSize' => 'Font size',
+        'StatsDisplayNumber' => 'Show numbers',
+        'StatsSave' => 'Save statistics image to a file',
+        'StatsAccumulate' => 'Accumulate values',
+        'StatsShowAllDates' => 'Show all dates',
     );
 }
 1;
