@@ -2,7 +2,7 @@ package GCOptions;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -25,7 +25,7 @@ package GCOptions;
 use strict;
 use Gtk2;
 
-our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
+our $DEFAULT_IMG_DIR='./.%FILE_BASE%_pictures/';
 
 {
     package GCOptionLoader;
@@ -159,7 +159,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 template         => "Hello %1,<br/><br/>You have borrowed my %2 since %3. I\'d like to get it back shortly.",
                 history          => "none|none|none|none|none",
                 historysize      => "5",
-                useRelativePaths => 0,
+                useRelativePaths => 1,
                 useTitleForPics  => 1,
                 expandersMode    => 'cut',
                 dateFormat       => '%d/%m/%Y',
@@ -217,7 +217,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
                 $self->error('read', $!);
             } # if
         } # if
-    
+
         if (!GCLang::loadLangs($self->lang) && $main)
         {
             $self->lang($DEFAULT_LANG);
@@ -232,6 +232,7 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         (my $lang = $self->lang) =~ s/(.*)/\L$1\E_$1/;
         $lang =~ s/_EN/_US/; # Fix for english
         $lang =~ s/_CS/_CZ/; # Fix for Czech
+        $lang =~ s/_ZH/_TW/; # Fix for Traditional Chinese
         $lang .= '.UTF-8';
         $lang = 'sr@Latn' if $lang =~ /^sr/;  # Fix for serbian        
         return $lang;
@@ -1843,20 +1844,22 @@ our $DEFAULT_IMG_DIR='./%FILE_BASE%_pictures/';
         }
         $self->createComponents;
         $self->initValues;
-
     }
     
     sub initValues
     {
         my $self = shift;
         $self->{show} = {};
-        
+
         foreach (@{$self->{fields}})
         {
             my $isShown = 1;
             $isShown = 0 if ($self->{options}->hidden =~ m/\|$_\|/);
             $self->{show}->{$_} = $isShown;
-            $self->{$_}->set_active($isShown);
+            # Only set active if field exists. Works around problems caused trying
+            # to open corrupted collections
+            $self->{$_}->set_active($isShown)
+                if exists $self->{$_};
         }
     }
     
