@@ -2,7 +2,7 @@ package GCPlugins::GCPluginsBase;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -33,6 +33,8 @@ use utf8;
     use URI::Escape;
     use HTML::Entities;
     use Encode;
+    use File::Spec;
+    
 
     sub new
     {
@@ -80,10 +82,10 @@ use utf8;
         my $title2 = encode($self->getSearchCharset, $self->{title});
         my $word = uri_escape($title2);
         $word =~ s/%20/+/g;
-
+        
         my $post;
         my $html;
-
+        
         # For multi-pass plugins, the plugin will have set the url to load for 
         # the next pass as nextUrl. If this doesn't exist, we're either on the 
         # first pass, or only using a one-pass plugin, so call getSearchUrl
@@ -114,29 +116,47 @@ use utf8;
                     if ! GCUtils::inArrayTest($_, @noConversion);
             }
         }
-        
+
     }
     
     sub loadPage
     {
         my ($self, $url, $post, $noSave) = @_;
+        my $debugPhase = $ENV{GCS_DEBUG_PLUGIN_PHASE};
+        my $debugFile;
+        $debugFile = File::Spec->tmpdir.'/'.GCUtils::getSafeFileName($url)
+	       if ($debugPhase > 0);
         $self->{loadedUrl} = $url if ! $noSave;
         my $response;
-        if ($post)
+        my $result;
+        if ($debugPhase != 2)
         {
-            $response = $ua->post($url, $post);
-            #$response = $self->{ua}->post($url, $post);
+            if ($post)
+            {
+                $response = $ua->post($url, $post);
+            }
+            else
+            {
+                $response = $ua->get($url);
+            }
+            eval {
+                $result = $response->decoded_content;
+            };
+            if ($debugPhase == 1)
+            {
+                open DEBUG_FILE, ">$debugFile";
+                print DEBUG_FILE ($result || $response->content);
+                close DEBUG_FILE;
+            }
         }
         else
         {
-            $response = $ua->get($url);
-            #$response = $self->{ua}->get($url);
+            local $/;
+            open DEBUG_FILE, "$debugFile";
+            $result = <DEBUG_FILE>;
+            utf8::decode($result);
         }
-        my $result;
-        eval {
-            $result = $response->decoded_content;
-        };
-        return $result || $response->content;
+        return $result || ($response && $response->content);
     }
     
     sub capWord
@@ -193,6 +213,39 @@ use utf8;
         return getCharset;
     }
     
+    # For some plugins, we need extra checks to determine if urls match
+    # the language the plugin is written for. This allows us to correctly determine
+    # if a drag and dropped url is handled by a particular plugin. If these
+    # checks are necessary, return 1, and make sure plugin handles the 
+    # the testURL function correctly
+    sub needsLanguageTest
+    {
+        return 0;
+    }   
+    
+    # Used to test if a given url is handled by the plugin. Only required if 
+    # needsLanguageTest is true.
+    sub testURL
+    {
+        my ($self, $url) = @_;    
+        return 1
+    }
+    
+    # Determines whether plugin should be the default plugins gcstar uses.
+    # Plugins with this attribute set will appear first in plugin list,
+    # and will be highlighted with a star icon. A returned value of 1 
+    # means the plugin is preferred if it's language matches the user's language,
+    # a returned value of 2 mean's it's preferred regardless of the language.
+    sub isPreferred
+    {
+        return 0;
+    }
+    
+    sub getPreferred
+    {
+        return isPreferred;
+    }
+  	     
     sub getNotConverted
     {
         my $self = shift;
@@ -247,7 +300,7 @@ use utf8;
     sub changeUrl
     {
         my ($self, $url) = @_;
-        
+
         return $url;
     }
     
@@ -255,6 +308,7 @@ use utf8;
     {
         my ($self, $url) = @_;
         $self->checkProxy;
+        $self->checkCookieJar;
         my $realUrl = $self->changeUrl($url);
         my $html = $self->loadPage($realUrl);
         $self->{parsingList} = 0;
@@ -310,7 +364,8 @@ use utf8;
     {
         my $self = shift;
         $ua->cookie_jar(HTTP::Cookies::Netscape->new(
-          'file' => "$self->{cookieJar}"));
+          'file' => "$self->{cookieJar}",
+          'autosave' => 1,));
     }
 
     # Used to set the number of passes the plugin requires
