@@ -2,7 +2,10 @@ package GCPlugins::GCbooks::GCAmazonDE;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
+#
+#  Updated 28/02/2010 by palto
+#    * fixed issue with retrieving the description texts
 #
 #  This file is part of GCstar.
 #
@@ -90,6 +93,16 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             {
                 $self->{curInfo}->{cover} = $self->extractImage($attr);
             }
+# Product Description - new code inserted by palto
+			elsif (($tagname eq "div") && ($attr->{class} eq 'productDescriptionWrapper'))
+			{
+				$self->{insideDesc} = 1;
+			}
+			elsif (($tagname eq "h3") && ($attr->{class} eq 'productDescriptionSource'))
+			{
+				$self->{insideDescSource} = 1;
+			}
+# end of new code from palto
         }
     }
 
@@ -98,6 +111,14 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
 		my ($self, $tagname) = @_;
         $self->{inside}->{$tagname}--;
         $self->{insideContent} = $self->{otherEditions} = 0 if $tagname eq 'div';
+# Product Description - new code inserted by palto
+# Description ends with </div> tag and could be split by other tags like html links.
+		if (($tagname eq "div") && ($self->{insideDesc}))
+		{
+			$self->{insideDesc} = 0;
+			$self->{curInfo}->{description} .= "\n\n";
+		}
+# end of new code from palto
     }
 
     sub text
@@ -148,10 +169,20 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                 $self->{curInfo}->{title} = $1;
                 $self->{curInfo}->{authors} = $2;
             }
+# Code added by palto to insert the description source into the description text (needed to distinguish multiple descritions)
+			elsif ($self->{insideDescSource})
+            {
+                $self->{curInfo}->{description} .= $origtext . ":\n";
+				$self->{insideDescSource} = 0;
+            }
+# Code modified by palto
+# Concatenate multiple text sections of the description 
             elsif ($self->{insideDesc})
             {
-                $self->{curInfo}->{description} = $origtext;
-                $self->{insideDesc} = 0;
+                $self->{curInfo}->{description} .= $origtext;
+#                $self->{insideDesc} = 0;
+# Removed here, will be cleared at the end of the <div> tag instead.
+# end of modifications from palto
             }
             elsif ($self->{insidePublisher})
             {
@@ -193,9 +224,9 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             }
             elsif ($self->{inside}->{b})
             {
-                $self->{insideDesc} = 1 if $origtext eq 'Kurzbeschreibung' 
-                                        || $origtext =~ /^Amazon.de/
-                                        || $origtext eq 'Aus der Amazon.de-Redaktion';
+#                $self->{insideDesc} = 1 if $origtext eq 'Kurzbeschreibung' 
+#			 	|| $origtext =~ /^Amazon.de/
+#   	                                   || $origtext eq 'kulturnews.de';
                 $self->{insidePublisher} = 1 if $origtext =~ /Verlag:/;
                 $self->{insideLanguage} = 1 if $origtext =~ /Sprache:/;
                 $self->{insideIsbn} = 1 if $origtext =~ /ISBN-13:/;
@@ -206,7 +237,7 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
                     $self->{insidePages} = 1;
                     $self->{insideDetails} = 0;
                 }
-            }        
+            }
         }
     } 
 
@@ -295,6 +326,7 @@ use GCPlugins::GCbooks::GCbooksAmazonCommon;
             $html =~ s|&#220;|Ü|g;
             $html =~ s|&#228;|ä|g;
             $self->{insideDesc} = 0;
+			$self->{insideDescSource} = 0;
             $self->{insidePublisher} = 0;
             $self->{insideLanguage} = 0;
             $self->{insideSerie} = 0;
