@@ -2,7 +2,7 @@ package GCPlugins::GCfilms::GCfilmsAmazonCommon;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -41,10 +41,14 @@ use GCPlugins::GCstar::GCAmazonCommon;
         
         $self->{codeField} = '';
         $self->{searchType} = 'dvd';
-        
-        return $self;
-    }    
 
+        return $self;
+    }
+        
+    sub getSearchFieldsArray
+    {
+        return ['title'];
+    }
 }
 
 1;
