@@ -2,7 +2,7 @@ package GCPlugins::GCgames::GCMobyGames;
 
 ###################################################
 #
-#  Copyright 2005-2009 Tian
+#  Copyright 2005-2010 Christian Jodar
 #
 #  This file is part of GCstar.
 #
@@ -93,34 +93,54 @@ use GCPlugins::GCgames::GCgamesCommon;
         $self->{inside}->{$tagname}++;
         if ($self->{parsingList})
         {
-            if ( ($tagname eq 'a') && ( substr($attr->{href},0,6) eq '/game/' ) )
+            if ( !$self->{insideSearchImage}
+              && ($tagname eq 'a')
+              && ( substr($attr->{href},0,6) eq '/game/' ) )
             {
-                    # This part is executed twice when a cover is available
-                    $self->{isGame} = 1;
-                    $self->{itemIdx}++;
-                    $self->{itemsList}[$self->{itemIdx}]->{url} = 'http://www.mobygames.com'.$attr->{href}.'';
-                    $self->{isName} = 1 ;
-            }
-            elsif ( ($self->{isGame} eq 1 ) && ($tagname eq 'img') )
-            {
-                    # If a cover is available , the previous part is execute twice, so I remove one
-                    $self->{itemIdx}--
-            }
-            elsif ( ($self->{isGame} eq 1 ) && ($tagname eq 'br') )
-            {
-                    if ( $self->{itemsList}[$self->{itemIdx}]->{released} eq '' )
+                # Test if there is a platform name in it
+                # (i.e. if we can find a second slash after game/ )
+                if ($attr->{href} =~ m|/game/[^/]*/|)
+                {
+                    if ($self->{currentName})
                     {
-                        $self->{isDate} = 1 ;
+                        $self->{itemIdx}++;
+                        $self->{itemsList}[$self->{itemIdx}]->{url} = 'http://www.mobygames.com'.$attr->{href}.'';
+                        $self->{itemsList}[$self->{itemIdx}]->{name} = $self->{currentName};
+                        $self->{isPlatform} = 1;
                     }
-                    elsif ( $self->{itemsList}[$self->{itemIdx}]->{platform} eq '' )
+                    else
                     {
-                        $self->{isPlatform} = 1 ;
+                        # This is a game we want to add
+                        $self->{isGame} = 1;
+                        $self->{itemIdx}++;
+                        $self->{itemsList}[$self->{itemIdx}]->{url} = 'http://www.mobygames.com'.$attr->{href}.'';
+                        $self->{isName} = 1 ;
                     }
-                    
+                }
+                else
+                {
+                    # We will need the name later
+                    $self->{isGameName} = 1;
+                }
             }
             elsif ( ($tagname eq 'a') && ( substr($attr->{href},0,7) eq '/search' ) )
             {
-                        $self->{isGame} = 0;
+                $self->{isGame} = 0;
+            }
+            elsif ($tagname eq 'div')
+            {
+                if ($attr->{class} eq 'searchResult')
+                {
+                    $self->{currentName} = '';
+                }
+                elsif ($attr->{class} eq 'searchImage')
+                {
+                    $self->{insideSearchImage} = 1;
+                }
+            }
+            elsif ($tagname eq 'em')
+            {
+                $self->{isDate} = 1;
             }
         }
         elsif ($self->{parsingTips})
@@ -201,7 +221,12 @@ use GCPlugins::GCgames::GCgamesCommon;
                         #/^coreGameCover/ && ($self->{isBox} = 1, last);
                         /^coreGameRelease/ && ($self->{isEditor} = 1, last);
                     }
-
+                    
+                    if ($attr->{class} =~ m/scoreBoxBig/)
+                    {
+                        $self->{isRating} = 1;
+                    }
+                    
                     if ($self->{curInfo}->{genre})
                     {
                         $self->{isGenre} = 0;
@@ -295,14 +320,21 @@ use GCPlugins::GCgames::GCgamesCommon;
                     last if $screen > 2;
                 }
             }
+            elsif ( ($tagname eq 'br') && ($self->{isDescription}) )
+            {
+                $self->{curInfo}->{description} .= "\n";
+            }
         }
     }
 
     sub end
     {
-	my ($self, $tagname) = @_;
-		
+        my ($self, $tagname) = @_;
         $self->{inside}->{$tagname}--;
+        if ($self->{parsingList} && ($tagname eq 'div'))
+        {
+            $self->{insideSearchImage} = 0;
+        }
     }
 
     sub text
@@ -313,22 +345,37 @@ use GCPlugins::GCgames::GCgamesCommon;
         {
             if ($self->{isName})
             {
-                $self->{itemsList}[$self->{itemIdx}]->{name} = $origtext;
-                $self->{isName} = 0;
-            }
-            elsif ($self->{isDate})
-            {
-                my ($dummy, $released) = split(/--/,$origtext);
-                $self->{itemsList}[$self->{itemIdx}]->{released} = $released;
-                $self->{isDate} = 0;
+                #$self->{itemsList}[$self->{itemIdx}]->{name} = $origtext;
+                if ($origtext !~ /^Game:/)
+                {
+                    if (!$self->{currentName})
+                    {
+                        $self->{itemsList}[$self->{itemIdx}]->{name} = $origtext;
+                    }
+                    $self->{isName} = 0;
+                }
             }
             elsif ($self->{isPlatform})
             {
                 $self->{itemsList}[$self->{itemIdx}]->{platform} = $origtext;
-                $self->{itemsList}[$self->{itemIdx}]->{platform} =~ s/Windows 3.x/PC/;
-                $self->{itemsList}[$self->{itemIdx}]->{platform} =~ s/Windows/PC/;
                 $self->{isPlatform} = 0;
             }
+            elsif ($self->{isGameName})
+            {
+                $self->{currentName} = $origtext;
+                $self->{isGameName} = 0;
+            }
+            elsif ($self->{isDate})
+            {
+                $self->{itemsList}[$self->{itemIdx}]->{released} = $origtext;
+                if (! $self->{itemsList}[$self->{itemIdx}]->{platform})
+                {
+                    $self->{previous} =~ s/[\s\(]*$//g;
+                    $self->{itemsList}[$self->{itemIdx}]->{platform} = $self->{previous};
+                }
+                $self->{isDate} = 0;
+            }
+            $self->{previous} = $origtext;
         }
         elsif ($self->{parsingTips})
         {
@@ -361,14 +408,7 @@ use GCPlugins::GCgames::GCgamesCommon;
                 }
                 elsif ($self->{is} eq 'genre')
                 {
-                    if ($self->{curInfo}->{genre})
-                    {
-                       $self->{curInfo}->{genre} .= ' / '.$origtext;
-                    }
-                    else
-                    {
-                       $self->{curInfo}->{genre} = $origtext;
-                    }
+                    push @{$self->{curInfo}->{genre}}, [ $origtext ];
                 }
                 else
                 {
@@ -377,6 +417,11 @@ use GCPlugins::GCgames::GCgamesCommon;
 
                 $self->{is} = '';
             }
+            elsif ($self->{isRating})
+            {
+                $self->{curInfo}->{ratingpress} = int($origtext/10+0.5);
+                $self->{isRating} = 0;
+            }
             elsif ($self->{isDescription})
             {
                     $self->{curInfo}->{description} .= $origtext;
@@ -447,7 +492,7 @@ use GCPlugins::GCgames::GCgamesCommon;
     sub getSearchUrl
     {
         my ($self, $word) = @_;
-        return 'http://www.mobygames.com/search/quick/p,-1/q,'.$word.'/showOnly,9/';
+        return 'http://www.mobygames.com/search/quick?q='.$word.'&p=-1&search=Go&sFilter=1&sG=on';
     }
     
     sub getItemUrl
